################################################################################
############ DATA IMPORT #######################################################
################################################################################

### import
setwd("XXX") #Set Working Directory
capt0<-read.table("capt.txt",header=T,na.strings="NA",dec=",")          ## Culicoides data (sites, dates, number, altitude)
puce<-read.table("temp_hr2.txt",header=T,na.strings="NA",dec=",")       ## temperature and humidity data recorded every 4 hours by field recorders
ndvi<-read.table("ndvi.txt",header=T,na.strings="NA",dec=",")           ## daily NDVI
pluie<-read.table("marg_pluie.txt",header=T,na.strings="NA",dec=",")    ## daily rain from weather stations
temp<-read.table("marg_temp.txt",header=T,na.strings="NA",dec=",")      ## daily temperature from weather station
vent<-read.table("marg_vent.txt",header=T,na.strings="NA",dec=",")      ## daily wind from weather station
hr<-read.table("marg_hr.txt",header=T,na.strings="NA",dec=",")          ## daily humidity from weather station
rg<-read.table("rg.txt",header=T,na.strings="NA",dec=",")               ## daily global radiation from weather station
site_data<-read.table("site_data.txt",header=T,na.strings="NA",dec=",") ## land use, animal & farm density, ecoclimate, building opening size, length of watercourses ...


#### let's keep only the useful columns in the Culicoides data
capt<-capt0[,which(names(capt0)==c("site","num_site","alti","espece","nombre","date","date_pos","date_recup","nb_femelle"))]


### date formatting
capt$date<-strptime(capt$date, "%d/%m/%Y")
capt$date_pos<-strptime(capt$date_pos, "%d/%m/%Y")
capt$date_recup<-strptime(capt$date_recup, "%d/%m/%Y")
puce$times<-strptime(puce$times, "%d/%m/%Y-%H:%M:%S")   
ndvi$date_ndvi<-strptime(ndvi$date_ndvi, "%d/%m/%Y")
pluie$date<-strptime(pluie$date, "%d/%m/%Y")
temp$date<-strptime(temp$date, "%d/%m/%Y")
vent$date_pos<-strptime(vent$date_pos, "%d/%m/%Y")
vent$date_recup<-strptime(vent$date_recup, "%d/%m/%Y")
hr$date<-strptime(hr$date, "%d/%m/%Y")
rg$date_pos<-strptime(rg$date_pos, "%d/%m/%Y")
rg$date_recup<-strptime(rg$date_recup, "%d/%m/%Y")

################################################################################
###### Addition of weather and environmental variables to the Culicoides data ##
################################################################################

### rain ######################################################################
capt$pluie_pos<-pluie$pluie[match(paste(capt$site,capt$date_pos), paste(pluie$site,pluie$date))]
capt$pluie_recup<-pluie$pluie[match(paste(capt$site,capt$date_recup), paste(pluie$site,pluie$date))]

### ndvi_est ###################################################################
capt$ndvi_est<-round(ndvi$ndvi_est[match(paste(capt$site,capt$date_pos), paste(ndvi$site,ndvi$date_ndvi))]/100,2)

### wind #######################################################################
capt$vent_pos<-vent$vent_pos_rect[match(paste(capt$site,capt$date_pos), paste(vent$site,vent$date_pos))]
capt$vent_recup<-vent$vent_recup_rect[match(paste(capt$site,capt$date_recup), paste(vent$site,vent$date_recup))]

### global radiation ###########################################################
capt$rg_pos<-round(rg$ray_global_pos[match(paste(capt$site,capt$date_pos), paste(rg$site,rg$date_pos))]/1000,2)
capt$rg_recup<-round(rg$ray_global_recup[match(paste(capt$site,capt$date_recup), paste(rg$site,rg$date_recup))]/1000,2)

### temp mean , min et max #####################################################
### daily temperature from field recorder
t_moy <- aggregate(temperature ~ jour + site + num_site  , puce, mean)
t_moy$temperature <- round(t_moy$temperature,2)
t_min<- aggregate(temperature ~ jour + site  , puce, min)
t_min$temperature <- round(t_min$temperature,2)
t_max<- aggregate(temperature ~ jour + site  , puce, max)
t_max$temperature <- round(t_max$temperature,2)

t_moy$t_min<-t_min$temperature[match(paste(t_moy$site,t_moy$jour), paste(t_min$site,t_min$jour))]
t_moy$t_max<-t_max$temperature[match(paste(t_moy$site,t_moy$jour), paste(t_max$site,t_max$jour))]

names(t_moy)<-c("date","site","num_site","t_moy","t_min","t_max")
t_moy<-t_moy[,c(2,3,1,4:6)]
t_moy$date<-strptime(t_moy$date, "%d/%m/%Y")
temp2<-rbind(temp,t_moy)

temp2<-temp2[-which(duplicated(temp2[,c(1,3)])),]  ## deletes the duplicates of the date 22/08/2017, by default those of the field recorders

capt$t_moy<-temp2$t_moy[match(paste(capt$site,capt$date_pos), paste(temp2$site,temp2$date))]
capt$t_minP<-temp2$t_min[match(paste(capt$site,capt$date_pos), paste(temp2$site,temp2$date))]
capt$t_maxP<-temp2$t_max[match(paste(capt$site,capt$date_pos), paste(temp2$site,temp2$date))]

### min and max temperature between two trapping sessions #######################
tm<-unique(capt[,c(1,7,8)])
tm$date_pos<-as.Date(tm$date_pos)
tm$date_recup<-as.Date(tm$date_recup)

tempx<-read.table("tempx.txt",header=T,na.strings="NA",dec=",") 
tempx$date<-strptime(tempx$date, "%d/%m/%Y")       ## date formatting

t_max_int<-NULL    
t_min_int<-NULL
for (i in 1:nrow(tm)){
t_max_int[i]<-max(tempx$t_max[c(match(paste(tm$site[i],tm$date_pos[i]-c(1:14)), paste(tempx$site,temp2$date)))],na.rm=TRUE)   
t_min_int[i]<-min(tempx$t_min[c(match(paste(tm$site[i],tm$date_pos[i]-c(1:14)), paste(tempx$site,temp2$date)))],na.rm=TRUE)    
   }   ## 2 minutes of computing time
   
tm$t_max_int<-replace(t_max_int,t_max_int==-Inf,NA)
tm$t_min_int<-replace(t_min_int,t_min_int==Inf,NA)

capt$t_max_interP<-tm$t_max_int[match(paste(capt$site,capt$date_pos), paste(tm$site,tm$date_pos))]
capt$t_min_interP<-tm$t_min_int[match(paste(capt$site,capt$date_pos), paste(tm$site,tm$date_pos))]

### humidity ###################################################################
hr2 <- aggregate(humidite ~ jour + site  , puce, mean)
hr2$humidite <- round(hr2$humidite,0)
hr2$jour <- strptime(hr2$jour, "%d/%m/%Y")
colnames(hr2)<-colnames(hr[,c(5,1,6)])
hr2<-rbind(hr2,hr[,c(5,1,6)])
hr2$hr<-replace(hr2$hr,hr2$hr>100,100) ## replaces humidity levels above 100% with 100% humidity
#head(hr2)

capt$hr<-hr2$hr[match(paste(capt$site,capt$date_pos), paste(hr2$site,hr2$date))]

### environmental data ################################################

capt<-cbind(capt,site_data[match(capt$site, site_data$site),3:50])

######## creation of a logistics response variable BME ######################### 
capt$BME <- as.logical(ifelse(capt$nombre == 0,0,1))

################################################################################
###### NA estimation
library(missMDA)

nbdim<-estim_ncpFAMD(capt[,c(10:70)])  ## selection of variables; 1000 bootstrap by default to determine the ncp
captx <- imputeFAMD(capt[,c(10:70)], ncp = 5)$completeObs    # 5
capt[,c(10:70)]<-captx
summary(capt)

## check that there are no outliers following the NA estimation (example: negative wind values)
## replace these values if necessary (example: reduce negative wind values to 0)

################################################################################
################  the species files are truncated to a date at least 52 days after 1st January 2016. 
################  time period necessary for the application of CCMs on a 50-day time frame
bol <-subset(capt, espece == "bolitinos" & date_pos>="2016-02-22 +03") 
ender <-subset(capt, espece == "enderleini"& date_pos>="2016-02-22 +03")
grah <-subset(capt, espece == "grahamii"& date_pos>="2016-02-22 +03")
imi <-subset(capt, espece == "imicola"& date_pos>="2016-02-22 +03")
kib <-subset(capt, espece == "kibatiensis"& date_pos>="2016-02-22 +03")

## save each species file with write.table
