############################################
####### data import

bol_tt3<-read.table("bol.txt",header=T)  
ender_tt3   <-read.table("ender.txt",header=T)
grah_tt3    <-read.table("grah.txt",header=T)
imi_tt3     <-read.table("imi.txt",header=T)
kib_tt3     <-read.table("kib.txt",header=T)

###############  random selection of 2/3 of the dates (i.e. 35 of the 52 dates)
###############  launch date.ent only once and save it
## date.ent<- sort(sample(unique(bol_tt3$date),35))
## save(file="date.ent",date.ent)
load("date.ent")
date.ent<-factor(date.ent)     ## dates of the training data
date.val<- factor(unique(bol_tt3$date)[!unique(bol_tt3$date) %in% date.ent])  ## remaining dates

bol.ent<-bol_tt3[bol_tt3$date %in% date.ent,] ## training data
bol.ent.zt  <- bol.ent[bol.ent$nombre > 0 ,]  ## training zero-truncated data

################################################################################
####### variable transformation : quantile
####### for rain, the first two quantiles are sometimes identical and must therefore be combined

nom.var= c("pluie_pos","pluie_recup","ndvi_est","vent_pos","vent_recup","rg_pos","rg_recup","t_moy","t_minP","t_maxP","t_max_interP","t_min_interP","hr") 
qt3<-lapply(nom.var, function (x) cut(bol_tt3[,x], breaks=c(-Inf,quantile(bol.ent[,x], c(1/3, 2/3), na.rm=TRUE),Inf), include.lowest = TRUE))
names(qt3)<-paste(nom.var,"qt3",sep="_")
qt4<-lapply(nom.var[nom.var!="pluie_recup" & nom.var!="pluie_pos"], function (x) cut(bol_tt3[,x], breaks=c(-Inf,quantile(bol.ent[,x], c(0.25, 0.5, 0.75), na.rm=TRUE),Inf), include.lowest = TRUE))
names(qt4)<-paste(nom.var[nom.var!="pluie_recup" & nom.var!="pluie_pos"],"qt4",sep="_")
qt5<-lapply(nom.var[nom.var!="pluie_recup" & nom.var!="pluie_pos"], function (x) cut(bol_tt3[,x], breaks=c(-Inf,quantile(bol.ent[,x], c(0.2, 0.4, 0.6, 0.8), na.rm=TRUE),Inf), include.lowest = TRUE))
names(qt5)<-paste(nom.var[nom.var!="pluie_recup" & nom.var!="pluie_pos"],"qt5",sep="_")
pluie_recup_qt4<- cut(bol_tt3[,"pluie_recup"], breaks=c(-Inf,quantile(bol.ent[,"pluie_recup"], c(0.5, 0.75), na.rm=TRUE),Inf), include.lowest = TRUE)
pluie_pos_qt4<- cut(bol_tt3[,"pluie_pos"], breaks=c(-Inf,quantile(bol.ent[,"pluie_pos"], c(0.5, 0.75), na.rm=TRUE),Inf), include.lowest = TRUE)
pluie_recup_qt5<- cut(bol_tt3[,"pluie_recup"], breaks=c(-Inf,quantile(bol.ent[,"pluie_recup"], c(0.4, 0.6, 0.8), na.rm=TRUE),Inf), include.lowest = TRUE)
pluie_pos_qt5<- cut(bol_tt3[,"pluie_pos"], breaks=c(-Inf,quantile(bol.ent[,"pluie_pos"], c(0.4, 0.6, 0.8), na.rm=TRUE),Inf), include.lowest = TRUE)

######## log10 transformation
######## reduce negative temperature values to 0
Xlog10<-lapply(nom.var[nom.var!="t_minP" & nom.var!="t_min_interP"], function (x) round(log10(bol_tt3[,x]+1),2))
names(Xlog10)<-paste(nom.var[nom.var!="t_minP" & nom.var!="t_min_interP"],"log10",sep="_")
t_minP_log10 <- round(log10(replace(bol_tt3$t_minP,bol_tt3$t_minP<0,0)+1),2)
t_min_interP_log10 <- round(log10(replace(bol_tt3$t_min_interP,bol_tt3$t_min_interP<0,0)+1),2)

## summary(bol_tt3)
bol_tt3<-as.data.frame(cbind(bol_tt3[,c(1:71)],qt3,qt4,pluie_recup_qt4,pluie_pos_qt4,qt5,pluie_recup_qt5,pluie_pos_qt5,Xlog10,t_minP_log10,t_min_interP_log10))
ender_tt3<-as.data.frame(cbind(ender_tt3[,c(1:71)],qt3,qt4,pluie_recup_qt4,pluie_pos_qt4,qt5,pluie_recup_qt5,pluie_pos_qt5,Xlog10,t_minP_log10,t_min_interP_log10))
grah_tt3<-as.data.frame(cbind(grah_tt3[,c(1:71)],qt3,qt4,pluie_recup_qt4,pluie_pos_qt4,qt5,pluie_recup_qt5,pluie_pos_qt5,Xlog10,t_minP_log10,t_min_interP_log10))
imi_tt3<-as.data.frame(cbind(imi_tt3[,c(1:71)],qt3,qt4,pluie_recup_qt4,pluie_pos_qt4,qt5,pluie_recup_qt5,pluie_pos_qt5,Xlog10,t_minP_log10,t_min_interP_log10))
kib_tt3<-as.data.frame(cbind(kib_tt3[,c(1:71)],qt3,qt4,pluie_recup_qt4,pluie_pos_qt4,qt5,pluie_recup_qt5,pluie_pos_qt5,Xlog10,t_minP_log10,t_min_interP_log10))

### recreate the training data.frame with the new varaibles
bol.ent<-bol_tt3[bol_tt3$date %in% date.ent,] ## training data
ender.ent<-ender_tt3[ender_tt3$date %in% date.ent,]
grah.ent<-grah_tt3[grah_tt3$date %in% date.ent,]
imi.ent<-imi_tt3[imi_tt3$date %in% date.ent,]
kib.ent<-kib_tt3[kib_tt3$date %in% date.ent,]

bol.ent.zt  <- bol.ent[bol.ent$nombre > 0 ,]  ## training zero-truncated data
ender.ent.zt  <- ender.ent[ender.ent$nombre > 0 ,]
grah.ent.zt  <- grah.ent[grah.ent$nombre > 0 ,]
imi.ent.zt  <- imi.ent[imi.ent$nombre > 0 ,]
kib.ent.zt  <- kib.ent[bol.ent$nombre > 0 ,]

################################################################################
######## class groupings are necessary if values less than 3 are observed in the following tables 
names(bol.ent)
zero.bol<-lapply(names(bol.ent[,72:110]), function(x) eval(parse(text=paste( "table(bol.ent$",x,",bol.ent$BME)"))))
names(zero.bol) = names(bol.ent[,72:110])
zero.bol

## repeat the operation for the other species
## example of grouping: # levels(ender_tt3$t_moy_qt3)=c("[-Inf,21.8]" ,"[-Inf,21.8]" ,"(21.8, Inf]")
## save

################################################################################
########## Lagged variable #########################################


### cf. step 1.1 CCM polyserial

### cf. step 1.2 CCM count

######################################################################
### complete the CCM data for all dates
pluiex<-read.table("pluiex.txt",header=T,na.strings="NA",dec=",")
tempx<-read.table("tempx.txt",header=T,na.strings="NA",dec=",")
hrx<-read.table("hrx.txt",header=T,na.strings="NA",dec=",")
ndvix<-read.table("ndvix.txt",header=T,na.strings="NA",dec=",")
ndvix$ndvi_est<-ndvix$ndvi_est/100
pluiex$date<-strptime(pluiex$date, "%d/%m/%Y")
tempx$date<-strptime(tempx$date, "%d/%m/%Y")
hrx$date<-strptime(hrx$date, "%d/%m/%Y")
ndvix$date_ndvi<-strptime(ndvix$date_ndvi, "%d/%m/%Y")
############ re-creation of matrixes for all dates. doing so for a single species is enough
############ times lags : nk=51 jours
library(fields)
nk=51; nj=nk
capt_bol<-bol_tt3

### rain
Xrr<-pluiex$pluie[match(paste(capt_bol$site,capt_bol$date_pos), paste(pluiex$site,pluiex$date))]
     for(j in 2:nj){
           Xrr <- cbind(Xrr,pluiex$pluie[match(paste(capt_bol$site,capt_bol$date_pos), paste(pluiex$site,pluiex$date))-j+1])}                    
Xlogrr<-log10(pluiex$pluie+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(pluiex$site,pluiex$date))]
     for(j in 2:nj){       
            Xlogrr<-cbind(Xlogrr,log10(pluiex$pluie+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(pluiex$site,pluiex$date))-j+1])}          

##### mean temperature
Xtmoy<-tempx$t_moy[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))]
     for(j in 2:nj){      
           Xtmoy<- cbind(Xtmoy,tempx$t_moy[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))-j+1])}           
Xlogtmoy<-log10(tempx$t_moy+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))]
     for(j in 2:nj){      
           Xlogtmoy<- cbind(Xlogtmoy,log10(tempx$t_moy+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))-j+1])}   

##### min temperature          
XtminP<-tempx$t_min[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))]
     for(j in 2:nj){      
           XtminP<- cbind(XtminP,tempx$t_min[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))-j+1])}           
XlogtminP<-log10(ifelse(tempx$t_min < 0,0,tempx$t_min)+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))]
     for(j in 2:nj){      
           XlogtminP<- cbind(XlogtminP,log10(ifelse(tempx$t_min < 0,0,tempx$t_min)+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))-j+1])}           

##### max temperature                   
XtmaxP<-tempx$t_max[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))]
     for(j in 2:nj){      
           XtmaxP<- cbind(XtmaxP,tempx$t_max[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))-j+1])}           
XlogtmaxP<-log10(tempx$t_max +1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))]
     for(j in 2:nj){      
           XlogtmaxP<- cbind(XlogtmaxP,log10(tempx$t_max +1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(tempx$site,tempx$date))-j+1])}                

##### humidity        
Xhr<-hrx$hr[match(paste(capt_bol$site,capt_bol$date_pos), paste(hrx$site,hrx$date))]
     for(j in 2:nj){      
           Xhr<- cbind(Xhr,hrx$hr[match(paste(capt_bol$site,capt_bol$date_pos), paste(hrx$site,hrx$date))-j+1])}           
Xloghr<-log10(hrx$hr+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(hrx$site,hrx$date))]
     for(j in 2:nj){      
           Xloghr<- cbind(Xloghr,log10(hrx$hr+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(hrx$site,hrx$date))-j+1])}           

##### ndvi
Xndvi_est<-ndvix$ndvi_est[match(paste(capt_bol$site,capt_bol$date_pos), paste(ndvix$site,ndvix$date_ndvi))]
     for(j in 2:nj){      
           Xndvi_est<- cbind(Xndvi_est,ndvix$ndvi_est[match(paste(capt_bol$site,capt_bol$date_pos), paste(ndvix$site,ndvix$date_ndvi))-j+1])}           
Xlogndvi_est<-log10(ndvix$ndvi_est+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(ndvix$site,ndvix$date_ndvi))]
     for(j in 2:nj){      
           Xlogndvi_est<- cbind(Xlogndvi_est,log10(ndvix$ndvi_est+1)[match(paste(capt_bol$site,capt_bol$date_pos), paste(ndvix$site,ndvix$date_ndvi))-j+1])}  


############ integration of lagged variables
############ the periods R(j,k) of each variable are to be reported manually from the CCM
############ be careful to add +1 to the value of R(j,k) to get the right line number

### bolitinos
ccm_bol<-cbind(Xhr[,(26+1)]                                       ,Xloghr[,(26+1)],
               Xndvi_est[,(50+1)]                                 ,Xlogndvi_est[,(50+1)],
               round(rowMeans(Xrr[,(24+1):(21+1)]),2)             ,Xlogrr[,(18+1)],
               Xtmoy[,(21+1)]                                     ,round(rowMeans(Xlogtmoy[,(3+1):(2+1)]),2),
               round(rowMeans(XtminP[,(2+1):(1+1)]),2)            ,round(rowMeans(XlogtminP[,(3+1):(1+1)]),2),
               XtmaxP[,(14+1)]                                    ,round(rowMeans(XlogtmaxP[,(15+1):(14+1)]),2),
                 Xndvi_est[,(18+1)]                               ,Xlogndvi_est[,(20+1)],
               round(rowMeans(Xhr[,(9+1):(8+1)],na.rm = TRUE),2)  ,round(rowMeans(Xloghr[,(9+1):(8+1)],na.rm = TRUE),2),
               round(rowMeans(Xndvi_est[,(4+1):(3+1)]),2)         ,round(rowMeans(Xlogndvi_est[,(5+1):(0+1)]),2),
               Xrr[,(9+1)]                                        ,round(rowMeans(Xlogrr[,(25+1):(23+1)]),2),
               Xtmoy[,(42+1)]                                     ,Xlogtmoy[,(42+1)],
               XtminP[,(41+1)]                                    ,XlogtminP[,(41+1)],
               XtmaxP[,(35+1)]                                    ,round(rowMeans(XlogtmaxP[,(35+1):(34+1)]),2),
                 Xtmoy[,(25+1)]                                   ,Xlogtmoy[,(25+1)],
                 XtminP[,(25+1)]                                  ,XlogtminP[,(10+1)],
                 round(rowMeans(XtmaxP[,(22+1):(21+1)]),2)        ,round(rowMeans(XlogtmaxP[,(22+1):(21+1)]),2))

colnames(ccm_bol)<-c("hr_26","loghr_26","ndvi_est_50","logndvi_est_50","pluie_24.21","log_pluie_18","tmoy_21","logtmoy_3.2","tminP_2.1","logtminP_3.1","tmaxP_14","logtmaxP_15.14",
                     "ndvi_est30d_18","logndvi_est30d_20",
                     "zt.hr_9.8","zt.loghr_9.8","zt.ndvi_est_4.3","zt.logndvi_est_5.0","zt.pluie_9","zt.log_pluie_25.23","zt.tmoy_42","zt.logtmoy_42","zt.tminP_41","zt.logtminP_41",
                     "zt.tmaxP_35","zt.logtmaxP_35.34",
                     "zt.tmoy30d_25","zt.logtmoy30d_25","zt.tminP30d_25","zt.logtminP30d_10",
                     "zt.tmaxP30d_22.21","zt.logtmaxP30d_22.21")
bol_tt3<-cbind(bol_tt3,ccm_bol) 


### enderleini
ccm_ender<-cbind(round(rowMeans(Xhr[,(41+1):(35+1)],na.rm = TRUE),2) ,round(rowMeans(Xloghr[,(27+1):(17+1)],na.rm = TRUE),2),
               Xndvi_est[,(50+1)]                                    ,Xlogndvi_est[,(50+1)],
               round(rowMeans(Xrr[,(48+1):(44+1)]),2)                ,Xlogrr[,(14+1)],
               round(rowMeans(Xtmoy[,(50+1):(0+1)]),2)               ,round(rowMeans(Xlogtmoy[,(50+1):(0+1)]),2),
               round(rowMeans(XtminP[,(49+1):(0+1)]),2)              ,round(rowMeans(XlogtminP[,(50+1):(1+1)]),2),
               round(rowMeans(XtmaxP[,(16+1):(10+1)]),2)             ,round(rowMeans(XlogtmaxP[,(16+1):(12+1)]),2),
                 round(rowMeans(Xhr[,(27+1):(17+1)],na.rm = TRUE),2) ,
                 Xndvi_est[,(30+1)]                                  ,Xlogndvi_est[,(30+1)],
                 Xrr[,(14+1)]                                        ,
                 round(rowMeans(Xtmoy[,(12+1):(10+1)]),2)            ,round(rowMeans(Xlogtmoy[,(30+1):(0+1)]),2),
                 round(rowMeans(XtminP[,(11+1):(10+1)]),2)           ,round(rowMeans(XlogtminP[,(28+1):(1+1)]),2),
               Xhr[,(15+1)]                                          ,Xloghr[,(15+1)],
               Xrr[,(9+1)]                                           ,Xlogrr[,(9+1)],
               Xndvi_est[,(50+1)]                                    ,Xlogndvi_est[,(50+1)],
               Xtmoy[,(15+1)]                                        ,Xlogtmoy[,(15+1)],
               round(rowMeans(XtminP[,(14+1):(13+1)]),2)             ,XlogtminP[,(14+1)],
               round(rowMeans(XtmaxP[,(28+1):(19+1)]),2)             ,round(rowMeans(XlogtmaxP[,(28+1):(19+1)]),2),
                 Xndvi_est[,(4+1)]                                   ,Xlogndvi_est[,(4+1)])

colnames(ccm_ender)<-c("hr_41.35","loghr_27.17","ndvi_est_50","logndvi_est_50","pluie_48.44","log_pluie_14","tmoy_50.0","logtmoy_50.0","tminP_49.0","logtminP_50.1","tmaxP_16.10","logtmaxP_16.12",
                     "hr30d_27.17","ndvi_est30d_30","logndvi_est30d_30","pluie30d_14","tmoy30d_12.10","logtmoy30d_30.0","tminP30d_11.10","logtminP30d_28.1",
                     "zt.hr_15","zt.loghr_15","zt.pluie_9","zt.log_pluie_9","zt.ndvi_est_50","zt.logndvi_est_50","zt.tmoy_15","zt.logtmoy_15","zt.tminP_14.13","zt.logtminP_14",
                     "zt.tmaxP_28.19","zt.logtmaxP_28.19",
                     "zt.ndvi_est30d_4","zt.logndvi_est30d_4")
ender_tt3<-cbind(ender_tt3,ccm_ender) 


### grahamii
ccm_grah<-cbind(round(rowMeans(Xhr[,(48+1):(43+1)],na.rm = TRUE),2)   ,round(rowMeans(Xloghr[,(48+1):(42+1)],na.rm = TRUE),2),
               Xndvi_est[,(31+1)]                                     ,Xlogndvi_est[,(31+1)],
               Xrr[,(48+1)]                                           ,round(rowMeans(Xlogrr[,(48+1):(47+1)]),2),
               Xtmoy[,(1+1)]                                          ,Xlogtmoy[,(1+1)],
               XtminP[,(2+1)]                                         ,XlogtminP[,(2+1)],
               XtmaxP[,(17+1)]                                        ,XlogtmaxP[,(17+1)],
                 round(rowMeans(Xhr[,(20+1):(15+1)],na.rm = TRUE),2)  ,round(rowMeans(Xloghr[,(20+1):(15+1)],na.rm = TRUE),2),
                 Xndvi_est[,(30+1)]                                   ,Xlogndvi_est[,(30+1)],
                 round(rowMeans(Xrr[,(29+1):(24+1)]),2)               ,round(rowMeans(Xlogrr[,(3+1):(2+1)]),2),
               Xhr[,(23+1)]                                           ,Xloghr[,(23+1)],
               round(rowMeans(Xrr[,(6+1):(5+1)]),2)                   ,round(rowMeans(Xlogrr[,(7+1):(5+1)]),2),
               Xndvi_est[,(21+1)]                                     ,Xlogndvi_est[,(20+1)],
               Xtmoy[,(15+1)]                                         ,Xlogtmoy[,(15+1)],
               XtminP[,(15+1)]                                        ,XlogtminP[,(15+1)],
               XtmaxP[,(50+1)]                                        ,XlogtmaxP[,(50+1)],
                 round(rowMeans(XtmaxP[,(8+1):(7+1)]),2)              ,round(rowMeans(XlogtmaxP[,(8+1):(7+1)]),2))

colnames(ccm_grah)<-c("hr_48.43","loghr_48.42","ndvi_est_31","logndvi_est_31","pluie_48","log_pluie_48.47","tmoy_1","logtmoy_1","tminP_2","logtminP_2","tmaxP_17","logtmaxP_17",
                     "hr30d_20.15","loghr30d_20.15","ndvi_est30d_30","logndvi_est30d_30","pluie30d_29.24","log_pluie30d_3.2",
                     "zt.hr_23","zt.loghr_23","zt.pluie_6.5","zt.log_pluie_7.5","zt.ndvi_est_21","zt.logndvi_est_20","zt.tmoy_15","zt.logtmoy_15","zt.tminP_15","zt.logtminP_15",
                     "zt.tmaxP_50","zt.logtmaxP_50",
                     "zt.tmaxP30d_8.7","zt.logtmaxP30d_8.7")
grah_tt3<-cbind(grah_tt3,ccm_grah) 


### imicola
ccm_imi<-cbind(round(rowMeans(Xhr[,(50+1):(0+1)],na.rm = TRUE),2)   ,round(rowMeans(Xloghr[,(50+1):(0+1)],na.rm = TRUE),2),
               Xndvi_est[,(48+1)]                                   ,Xlogndvi_est[,(48+1)],
               Xrr[,(4+1)]                                          ,round(rowMeans(Xlogrr[,(5+1):(3+1)]),2),
               round(rowMeans(Xtmoy[,(45+1):(27+1)]),2)             ,round(rowMeans(Xlogtmoy[,(43+1):(33+1)]),2),
               round(rowMeans(XtminP[,(50+1):(4+1)]),2)             ,round(rowMeans(XlogtminP[,(39+1):(33+1)]),2),
               round(rowMeans(XtmaxP[,(5+1):(0+1)]),2)              ,round(rowMeans(XlogtmaxP[,(48+1):(0+1)]),2),
                 round(rowMeans(Xhr[,(24+1):(0+1)],na.rm = TRUE),2) ,round(rowMeans(Xloghr[,(24+1):(0+1)],na.rm = TRUE),2),
                 Xndvi_est[,(30+1)]                                 ,Xlogndvi_est[,(30+1)],
                 Xtmoy[,(5+1)]                                      ,round(rowMeans(Xlogtmoy[,(10+1):(4+1)]),2),
                 round(rowMeans(XtminP[,(10+1):(4+1)]),2)           ,round(rowMeans(XlogtminP[,(28+1):(4+1)]),2),
                                                                     round(rowMeans(XlogtmaxP[,(5+1):(0+1)]),2),
               round(rowMeans(Xhr[,(50+1):(32+1)],na.rm = TRUE),2)  ,round(rowMeans(Xloghr[,(50+1):(32+1)],na.rm = TRUE),2),
               round(rowMeans(Xrr[,(50+1):(0+1)]),2)                ,round(rowMeans(Xlogrr[,(50+1):(1+1)]),2),
               Xndvi_est[,(50+1)]                                   ,round(rowMeans(Xlogndvi_est[,(50+1):(48+1)]),2),               
               Xtmoy[,(26+1)]                                       ,round(rowMeans(Xlogtmoy[,(33+1):(31+1)]),2),
               round(rowMeans(XtminP[,(24+1):(22+1)]),2)            ,round(rowMeans(XlogtminP[,(24+1):(22+1)]),2),
               round(rowMeans(XtmaxP[,(32+1):(1+1)]),2)             ,round(rowMeans(XlogtmaxP[,(32+1):(5+1)]),2),
                 Xhr[,(26+1)]                                       ,Xloghr[,(26+1)],
                 round(rowMeans(Xrr[,(27+1):(0+1)]),2)              ,round(rowMeans(Xlogrr[,(27+1):(15+1)]),2),
                 Xndvi_est[,(30+1)]                                 ,Xlogndvi_est[,(30+1)],                 
                                                                     round(rowMeans(Xlogtmoy[,(26+1):(22+1)]),2),
                 round(rowMeans(XtmaxP[,(26+1):(1+1)]),2)           ,round(rowMeans(XlogtmaxP[,(26+1):(1+1)]),2))

colnames(ccm_imi)<-c("hr_50.0","loghr_50.0","ndvi_est_48","logndvi_est_48","pluie_4","log_pluie_5.3","tmoy_45.27","logtmoy_43.33","tminP_50.4","logtminP_39.33","tmaxP_5.0","logtmaxP_48.0",
                     "hr30d_24.0","loghr30d_24.0","ndvi_est30d_30","logndvi_est30d_30","tmoy30d_5","logtmoy30d_10.4","tminP30d_10.4","logtminP30d_28.4","logtmaxP30d_5.0",
                     "zt.hr_50.32","zt.loghr_50.32","zt.pluie_50.0","zt.log_pluie_50.1","zt.ndvi_est_50","zt.logndvi_est_50.48","zt.tmoy_26","zt.logtmoy_33.31","zt.tminP_24.22",
                     "zt.logtminP_24.22","zt.tmaxP_32.1","zt.logtmaxP_32.5",
                     "zt.hr30d_26","zt.loghr30d_26","zt.pluie30d_27.0","zt.log_pluie30d_27.15","zt.ndvi_est30d_30","zt.logndvi_est30d_30","zt.logtmoy30d_26.22",
                     "zt.tmaxP30d_26.1","zt.logtmaxP30d_26.1")
imi_tt3<-cbind(imi_tt3,ccm_imi)   


### kibatiensis
ccm_kib<-cbind(round(rowMeans(Xhr[,(50+1):(3+1)],na.rm = TRUE),2)   ,round(rowMeans(Xloghr[,(50+1):(4+1)],na.rm = TRUE),2),
               Xndvi_est[,(29+1)]                                   ,Xlogndvi_est[,(29+1)],
               Xrr[,(18+1)]                                         ,round(rowMeans(Xlogrr[,(11+1):(10+1)]),2),
               Xtmoy[,(2+1)]                                        ,Xlogtmoy[,(5+1)],
               round(rowMeans(XtminP[,(2+1):(1+1)]),2)              ,round(rowMeans(XlogtminP[,(5+1):(4+1)]),2),
               round(rowMeans(XtmaxP[,(16+1):(11+1)]),2)            ,round(rowMeans(XlogtmaxP[,(16+1):(11+1)]),2),
                 round(rowMeans(Xhr[,(25+1):(4+1)],na.rm = TRUE),2) ,round(rowMeans(Xloghr[,(25+1):(4+1)],na.rm = TRUE),2),               
               round(rowMeans(Xhr[,(3+1):(0+1)],na.rm = TRUE),2)    ,round(rowMeans(Xloghr[,(3+1):(0+1)],na.rm = TRUE),2),
               Xrr[,(48+1)]                                         ,Xlogrr[,(4+1)],
               Xndvi_est[,(36+1)]                                   ,Xlogndvi_est[,(36+1)],                            
               Xtmoy[,(45+1)]                                       ,Xlogtmoy[,(36+1)],
               XtminP[,(46+1)]                                      ,XlogtminP[,(46+1)],
               XtmaxP[,(44+1)]                                      ,XlogtmaxP[,(44+1)],
                 Xndvi_est[,(30+1)]                                 ,Xlogndvi_est[,(11+1)],
                 round(rowMeans(Xrr[,(16+1):(15+1)]),2)             ,
                 Xtmoy[,(25+1)]                                     ,Xlogtmoy[,(13+1)],
                 round(rowMeans(XtminP[,(25+1):(24+1)]),2)          ,XlogtminP[,(24+1)],
                 XtmaxP[,(15+1)]                                    ,XlogtmaxP[,(15+1)])

colnames(ccm_kib)<-c("hr_50.3","loghr_50.4","ndvi_est_29","logndvi_est_29","pluie_18","log_pluie_11.10","tmoy_2","logtmoy_5","tminP_2.1","logtminP_5.4","tmaxP_16.11","logtmaxP_16.11",
                     "hr30d_25.4","loghr30d_25.4",
                     "zt.hr_3.0","zt.loghr_3.0","zt.pluie_48","zt.log_pluie_4","zt.ndvi_est_36","zt.logndvi_est_36","zt.tmoy_45","zt.logtmoy_36","zt.tminP_46","zt.logtminP_46",
                     "zt.tmaxP_44","zt.logtmaxP_44",
                     "zt.ndvi_est30d_30","zt.logndvi_est30d_11","zt.pluie30d_16.15","zt.tmoy30d_25","zt.logtmoy30d_13","zt.tminP30d_25.24","zt.logtminP30d_24",
                     "zt.tmaxP30d_15","zt.logtmaxP30d_15")
kib_tt3<-cbind(kib_tt3,ccm_kib) 


###### deal with the remaining NA on humidity variables
library(missMDA)

names(bol_tt3)
bol_ttx <- imputeFAMD(bol_tt3[,c(1,5,10:70,72:length(bol_tt3))], ncp = 5)$completeObs
bol_tt3[,c("hr_26","loghr_26","zt.hr_9.8","zt.loghr_9.8")]<-bol_ttx[,c("hr_26","loghr_26","zt.hr_9.8","zt.loghr_9.8")]

ender_ttx <- imputeFAMD(ender_tt3[,c(1,5,10:70,72:length(ender_tt3))], ncp = 5)$completeObs
ender_tt3[,c("hr_41.35","loghr_27.17","hr30d_27.17","zt.hr_15","zt.loghr_15")]<-ender_ttx[,c("hr_41.35","loghr_27.17","hr30d_27.17","zt.hr_15","zt.loghr_15")]

grah_ttx <- imputeFAMD(grah_tt3[,c(1,5,10:70,72:length(grah_tt3))], ncp = 5)$completeObs
grah_tt3[,c("hr_48.43","loghr_48.42","hr30d_20.15","loghr30d_20.15","zt.hr_23","zt.loghr_23")]<-grah_ttx[,c("hr_48.43","loghr_48.42","hr30d_20.15","loghr30d_20.15","zt.hr_23","zt.loghr_23")]

imi_ttx <- imputeFAMD(imi_tt3[,c(1,5,10:70,72:length(imi_tt3))], ncp = 5)$completeObs
imi_tt3[,c("hr_50.0","loghr_50.0","hr30d_24.0","loghr30d_24.0","zt.hr_50.32","zt.loghr_50.32","zt.hr30d_26","zt.loghr30d_26")]<-imi_ttx[,c("hr_50.0","loghr_50.0","hr30d_24.0","loghr30d_24.0","zt.hr_50.32","zt.loghr_50.32","zt.hr30d_26","zt.loghr30d_26")]

kib_ttx <- imputeFAMD(kib_tt3[,c(1,5,10:70,72:length(kib_tt3))], ncp = 5)$completeObs
kib_tt3[,c("hr_50.3","loghr_50.4","hr30d_25.4","loghr30d_25.4","zt.hr_3.0","zt.loghr_3.0")]<-kib_ttx[,c("hr_50.3","loghr_50.4","hr30d_25.4","loghr30d_25.4","zt.hr_3.0","zt.loghr_3.0")]


###### rescale ndvi
bol_tt3$ndvi_est<-bol_tt3$ndvi_est*100
bol_tt3$ndvi_est_log10<-round(log10(bol_tt3$ndvi_est),2)

ender_tt3$ndvi_est<-ender_tt3$ndvi_est*100
ender_tt3$ndvi_est_log10<-round(log10(ender_tt3$ndvi_est),2)

grah_tt3$ndvi_est<-grah_tt3$ndvi_est*100
grah_tt3$ndvi_est_log10<-round(log10(grah_tt3$ndvi_est),2)

imi_tt3$ndvi_est<-imi_tt3$ndvi_est*100
imi_tt3$ndvi_est_log10<-round(log10(imi_tt3$ndvi_est),2)

kib_tt3$ndvi_est<-kib_tt3$ndvi_est*100
kib_tt3$ndvi_est_log10<-round(log10(kib_tt3$ndvi_est),2)

######## save each file

