################################################################################
########### IMPORT DATA ########################################################
################################################################################


bol_tt3     <-read.table("bol_tt3.txt",header=T)  
ender_tt3   <-read.table("ender_tt3.txt",header=T)
grah_tt3    <-read.table("grah_tt3.txt",header=T)
imi_tt3     <-read.table("imi_tt3.txt",header=T)
kib_tt3     <-read.table("kib_tt3.txt",header=T)

load("date.ent")
date.ent<-factor(date.ent)
date.val<- factor(unique(bol_tt3$date)[!unique(bol_tt3$date) %in% date.ent])

## training data
bol.ent<-bol_tt3[bol_tt3$date %in% date.ent,]
ender.ent<-ender_tt3[ender_tt3$date %in% date.ent,]
grah.ent<-grah_tt3[grah_tt3$date %in% date.ent,]
imi.ent<-imi_tt3[imi_tt3$date %in% date.ent,]
kib.ent<-kib_tt3[kib_tt3$date %in% date.ent,]
################################################################################
##### it's possible to test the overdispersion and zero-inflated after the creation of these training data
##### cf. step 2.0 ZI and OD test
################################################################################

## validation data
bol.ve<-bol_tt3[!bol_tt3$date %in% date.ent,]
ender.ve<-ender_tt3[!ender_tt3$date %in% date.ent,]
grah.ve<-grah_tt3[!grah_tt3$date %in% date.ent,]
imi.ve<-imi_tt3[!imi_tt3$date %in% date.ent,]
kib.ve<-kib_tt3[!kib_tt3$date %in% date.ent,]

### keep only the variables useful for the logistic regression
### 
bol.COmm <-bol.ent[,c(1,10:137)]
ender.COmm <-ender.ent[,c(1,10:143)]
grah.COmm  <-grah.ent[,c(1,10:141)]
imi.COmm   <-imi.ent[,c(1,10:144)]
kib.COmm   <-kib.ent[,c(1,10:137)]

## names of the variables
nom.bol = names(bol.COmm[,(names(bol.COmm)!="BME" & names(bol.COmm)!="site")])
nom.ender = names(ender.COmm[,(names(ender.COmm)!="BME" & names(ender.COmm)!="site")])
nom.grah = names(grah.COmm[,(names(grah.COmm)!="BME" & names(grah.COmm)!="site")])
nom.imi = names(imi.COmm[,(names(imi.COmm)!="BME" & names(imi.COmm)!="site")])
nom.kib = names(kib.COmm[,(names(kib.COmm)!="BME" & names(kib.COmm)!="site")])

################################################################################
##############library 

library(lme4)
library(lmerTest)
library(arm)
library(car)


################################################################################
############## univariate analysis
## improvement of control see https://stats.idre.ucla.edu/r/dae/mixed-effects-logistic-regression/
## laplace approximation replaced by log-likehood approximation by quadrature hermit gauss with 10 control points per axis (nAGQ = 10)
## gauss hermit quadrature will give a better precision in the evaluation of the log-likehood
## the glmer control avoids error messages due to the convergence defaillace

logit<-"logit"
bobyqa<-"bobyqa"
                                                  
mod_bin.bolmm<-lapply(nom.bol, function(x) eval(parse(text=paste( "glmer(BME ~",x,"+(1|site), data = bol.COmm, family = binomial(link=",logit,"),control = glmerControl(optimizer = ",bobyqa,"),nAGQ = 10)"))))
mod_bin.endermm<-lapply(nom.ender, function(x) eval(parse(text=paste( "glmer(BME ~",x,"+(1|site), data = ender.COmm, family = binomial(link=",logit,"),control = glmerControl(optimizer = ",bobyqa,"),nAGQ = 10)"))))
mod_bin.grahmm<-lapply(nom.grah, function(x) eval(parse(text=paste( "glmer(BME ~",x,"+(1|site), data = grah.COmm, family = binomial(link=",logit,"),control = glmerControl(optimizer = ",bobyqa,"),nAGQ = 10)"))))
mod_bin.imimm<-lapply(nom.imi, function(x) eval(parse(text=paste( "glmer(BME ~",x,"+(1|site), data = imi.COmm, family = binomial(link=",logit,"),control = glmerControl(optimizer = ",bobyqa,"),nAGQ = 10)"))))
mod_bin.kibmm<-lapply(nom.kib, function(x) eval(parse(text=paste( "glmer(BME ~",x,"+(1|site), data = kib.COmm, family = binomial(link=",logit,"),control = glmerControl(optimizer = ",bobyqa,"),nAGQ = 10)"))))

names(mod_bin.bolmm) = nom.bol
names(mod_bin.endermm) = nom.ender
names(mod_bin.grahmm) = nom.grah
names(mod_bin.imimm) = nom.imi
names(mod_bin.kibmm) = nom.kib

## calculation of p-values
ano_bin.bolmm<-lapply(mod_bin.bolmm, function(x) Anova(x))
#summary_bin.bolmm<-lapply(mod_bin.bolmm, function(x) summary(x))
ano_bin.endermm<-lapply(mod_bin.endermm, function(x) Anova(x))
ano_bin.grahmm<-lapply(mod_bin.grahmm, function(x) Anova(x))
ano_bin.imimm<-lapply(mod_bin.imimm, function(x) Anova(x))
ano_bin.kibmm<-lapply(mod_bin.kibmm, function(x) Anova(x))

### selection of variables with p-values < 0.2
sortie.bin.bolmm<-sapply(ano_bin.bolmm,function(x) x$Pr)
tri.bin.bolmm<-(sortie.bin.bolmm)[sortie.bin.bolmm<0.2]
sortie.bin.endermm<-sapply(ano_bin.endermm,function(x) x$Pr)
tri.bin.endermm<-(sortie.bin.endermm)[sortie.bin.endermm<0.2]
sortie.bin.grahmm<-sapply(ano_bin.grahmm,function(x) x$Pr)
tri.bin.grahmm<-(sortie.bin.grahmm)[sortie.bin.grahmm<0.2]
sortie.bin.imimm<-sapply(ano_bin.imimm,function(x) x$Pr)
tri.bin.imimm<-(sortie.bin.imimm)[sortie.bin.imimm<0.2]
sortie.bin.kibmm<-sapply(ano_bin.kibmm,function(x) x$Pr)
tri.bin.kibmm<-(sortie.bin.kibmm)[sortie.bin.kibmm<0.2]


## visualization barplot for elimination of duplicate variables
par(mai=c(2,1,1,1))
barplot(tri.bin.bolmm[sort(names(tri.bin.bolmm))],las=2,cex.lab=0.8,main="bolitinos logistique 2")   
par(mai=c(2,1,1,1))
barplot(tri.bin.endermm[sort(names(tri.bin.endermm))],las=2,cex.lab=0.8,main="enderleini logistique 2")  
par(mai=c(2,1,1,1))
barplot(tri.bin.grahmm[sort(names(tri.bin.grahmm))],las=2,cex.lab=0.8,main="grahamii logistique 2")   
par(mai=c(2,1,1,1))
barplot(tri.bin.imimm[sort(names(tri.bin.imimm))],las=2,cex.lab=0.8,main="imicola logistique 2")   
par(mai=c(2,1,1,1))
barplot(tri.bin.kibmm[sort(names(tri.bin.kibmm))],las=2,cex.lab=0.8,main="kibatiensis logistique 2")   


###### are only kept:
###### the variables providing the best information : numerical > quantile qt5 ... quantile qt3 > log10
###### variables whose univariate analysis has converged correctly (i.e. without warning message)

good_bolmm <- c("anx_cible","bov0.5","bov1","cult_maraich0.5","cult_maraich1","cult_maraich2","logtmoy_3.2","nbsite0.5",
           "nbsite2","ndvi_est","ndvi_est30d_18","petit_ru0.5","petit_ru1","plant_forest0.5","plant_forest1","plant_forest2",
           "pluie_24.21","pluie_pos_qt5","prairie0.5","t_maxP","t_min_interP_qt4","t_minP","t_moy","tmaxP_14",
           "tminP_2.1","tmoy_21","tot_anx0.5","tot_anx1","verger0.5","verger1","verger2")

good_endermm <-c("bov1","bov2","canne0.5","canne1","canne2","daupi","foret0.5","foret1","foret2","hr","hr_41.35","hr30d_27.17",
             "hydro0.5","hydro1","hydro2","logtminP30d_28.1","logtmoy30d_30.0","nbsite2","ndvi_est","ndvi_est_50","plant_forest2",
             "pluie_48.44","pluie_pos_qt3","pluie_recup_qt5","pluie30d_14","prairie0.5","prairie1","prairie2",
             "rg_recup","roche_nue1","roche_nue2","t_max_interP","t_maxP","t_min_interP","t_minP","t_moy","tmaxP_16.10","tminP_49.0",
             "tminP30d_11.10","tmoy_50.0","tmoy30d_12.10","tot_anx2","vent_pos","vent_recup","verger0.5","verger1","verger2",
             "zone_urb0.5","zone_urb1","zone_urb2")

good_grahmm <-c("autre0.5","autre1","autre2","canne0.5","canne1","canne2","daupi","foret0.5","foret1","foret2","hr_48.43",
            "hr30d_20.15","hydro0.5","hydro1","hydro2","log_pluie30d_3.2","nbsite2","ndvi_est","ndvi_est_31","petit_ru0.5",
            "pluie_48","pluie_pos_qt5","pluie30d_29.24","prairie0.5","prairie1","prairie2","rg_pos","rg_recup","roche_nue1",
            "roche_nue2","savane1","savane2","t_max_interP","t_minP_qt5","t_moy_qt5","tminP_2","vent_pos","vent_recup",
            "verger0.5","verger1","zone_urb0.5","zone_urb1")

good_imimm <-c("bov0.5","bov1","bov2","daupi","foret2","hr_qt5","hydro2","logtmaxP_48.0","logtminP_39.33","logtminP30d_28.4",
           "logtmoy_43.33","logtmoy30d_10.4","nbsite0.5","nbsite1","nbsite2","ndvi_est_qt5","ouv_bat","petit_ru1","plant_forest0.5",
           "plant_forest1","plant_forest2","pluie_4","pluie_recup","prairie0.5","prairie1","prairie2","roche_nue1",
           "roche_nue2","savane0.5","savane1","savane2","t_max_interP","t_maxP","t_min_interP","t_minP","t_moy","tmaxP_5.0",
           "tminP_50.4","tminP30d_10.4","tmoy_45.27","tmoy30d_5","tot_anx0.5","tot_anx1","tot_anx2","vent_pos","vent_recup",
           "verger0.5","verger1","verger2","zone_urb0.5","zone_urb1","zone_urb2")

good_kibmm <-c("autre2","canne0.5","canne1","canne2","daupi","foret0.5","foret1","foret2","hr_50.3","hr30d_25.4","hydro0.5",
           "hydro1","hydro2","log_pluie_11.10","logtmoy_5","ndvi_est_29","petit_ru0.5","plant_forest1","plant_forest2","pluie_18",
           "pluie_pos","prairie0.5","prairie1","prairie2","rg_recup","roche_nue1","roche_nue2","t_max_interP","t_maxP",
           "t_min_interP","t_minP","t_moy","tmaxP_16.11","tminP_2.1","tmoy_2","vent_pos","verger0.5","verger1","verger2","zone_urb0.5",
           "zone_urb1","zone_urb2")
           

tribin.bolmm<-bol.COmm[,c(good_bolmm,"BME","site")]
tribin.endermm<-ender.COmm[,c(good_endermm,"BME","site")]
tribin.grahmm<-grah.COmm[,c(good_grahmm,"BME","site")]
tribin.imimm<-imi.COmm[,c(good_imimm,"BME","site")]
tribin.kibmm<-kib.COmm[,c(good_kibmm,"BME","site")]


################################################################################
######## multivariate analysis

tribin.bolmm_mod0 <- glmer(as.formula(paste("BME ~ ", paste(good_bolmm, collapse= "+"),"+(1|site)")), data=tribin.bolmm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)
tribin.endermm_mod0 <- glmer(as.formula(paste("BME ~ ", paste(good_endermm, collapse= "+"),"+(1|site)")), data=tribin.endermm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)
tribin.grahmm_mod0 <- glmer(as.formula(paste("BME ~ ", paste(good_grahmm, collapse= "+"),"+(1|site)")), data=tribin.grahmm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)
tribin.imimm_mod0 <- glmer(as.formula(paste("BME ~ ", paste(good_imimm, collapse= "+"),"+(1|site)")), data=tribin.imimm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)
tribin.kibmm_mod0 <- glmer(as.formula(paste("BME ~ ", paste(good_kibmm, collapse= "+"),"+(1|site)")), data=tribin.kibmm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)

#### coefficient verification and variance inflation analysis
tribin.bol_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_bolmm, collapse= "+"))), data=tribin.bolmm, family=binomial(link="logit"))
tribin.ender_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_endermm, collapse= "+"))), data=tribin.endermm, family=binomial(link="logit"))
tribin.grah_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_grahmm, collapse= "+"))), data=tribin.grahmm, family=binomial(link="logit"))
tribin.imi_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_imimm, collapse= "+"))), data=tribin.imimm, family=binomial(link="logit"))
tribin.kib_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_kibmm, collapse= "+"))), data=tribin.kibmm, family=binomial(link="logit"))

################################################################################
######## collinearity analysis on mean model (glm) ############################

### cf. step 2.1 collinearity analysis


### variable to be deleted: 

vif.bol3<-c("plant_forest1","plant_forest2","prairie0.5","tot_anx0.5","tot_anx1","verger0.5","verger1",
"verger2","cult_maraich1","t_moy","bov0.5","logtmoy_3.2","cult_maraich2","tminP_2.1","tmoy_21","bov1","t_minP","petit_ru1")
vif.ender3<-c("hydro0.5","hydro1","hydro2","plant_forest2","prairie0.5","prairie2","roche_nue1","roche_nue2",
"tot_anx2","verger0.5","verger1","zone_urb0.5","zone_urb1","zone_urb2","canne1","canne0.5","foret1","tmoy_50.0",
"logtminP30d_28.1","bov2","t_moy","tmoy30d_12.10","logtmoy30d_30.0","canne2","tminP_49.0","t_minP","foret0.5",
"vent_recup","tminP30d_11.10","t_min_interP","tmaxP_16.10")
vif.grah3<-c("autre1","foret2","hydro0.5","hydro1","hydro2","nbsite2","petit_ru0.5","prairie0.5","prairie1",
"prairie2","roche_nue1","savane1","savane2","verger0.5","zone_urb0.5","zone_urb1","canne1","canne0.5","foret1",
"canne2","foret0.5","tminP_2")
vif.imi3<- c("nbsite2","plant_forest0.5","plant_forest1","plant_forest2","prairie0.5","prairie1","prairie2",
"roche_nue1","roche_nue2","savane0.5","savane1","savane2","tot_anx0.5","tot_anx1","tot_anx2","verger0.5","verger1",
"verger2","zone_urb0.5","zone_urb1","bov2","tminP_50.4","tmoy_45.27","bov1","t_moy","logtmoy30d_10.4","logtmoy_43.33",
"nbsite0.5","tmaxP_5.0","tminP30d_10.4","logtminP30d_28.4","logtmaxP_48.0","nbsite1","foret2","t_minP","tmoy30d_5",
"t_min_interP","hydro2","logtminP_39.33")
vif.kib3 <- c("foret2","hydro0.5","hydro1","hydro2","petit_ru0.5","plant_forest1","plant_forest2","prairie0.5",
         "prairie1","prairie2","roche_nue1","verger0.5","verger1","verger2","zone_urb0.5","zone_urb1","canne0.5",
         "canne1","canne2","t_moy","foret1","tmoy_2","tminP_2.1","hr30d_25.4","logtmoy_5","foret0.5","t_minP","t_min_interP",
         "tmaxP_16.11")

################################################################################
########## multivariate models

### mean models
tribin.bol_mod2 <- glm(as.formula(paste("BME ~ ", paste(good_bolmm[!good_bolmm %in% vif.bol3], collapse= "+"))), data=tribin.bolmm, family=binomial(link="logit"))
tribin.ender_mod2 <- glm(as.formula(paste("BME ~ ", paste(good_endermm[!good_endermm %in% vif.ender3], collapse= "+"))), data=tribin.endermm, family=binomial(link="logit"))
tribin.grah_mod2 <- glm(as.formula(paste("BME ~ ", paste(good_grahmm[!good_grahmm %in% vif.grah3], collapse= "+"))), data=tribin.grahmm, family=binomial(link="logit"))
tribin.imi_mod2 <- glm(as.formula(paste("BME ~ ", paste(good_imimm[!good_imimm %in% vif.imi3], collapse= "+"))), data=tribin.imimm, family=binomial(link="logit"))
tribin.kib_mod2 <- glm(as.formula(paste("BME ~ ", paste(good_kibmm[!good_kibmm %in% vif.kib3], collapse= "+"))), data=tribin.kibmm, family=binomial(link="logit"))

############## stepAIC on mean models
tribin.bol_mod3<-stepAIC(tribin.bol_mod2,dir="both")
tribin.ender_mod3<-stepAIC(tribin.ender_mod2,dir="both")
tribin.grah_mod3<-stepAIC(tribin.grah_mod2,dir="both")
tribin.imi_mod3<-stepAIC(tribin.imi_mod2,dir="both")
tribin.kib_mod3<-stepAIC(tribin.kib_mod2,dir="both")

Anova(tribin.bol_mod3)
Anova(tribin.ender_mod3)
Anova(tribin.grah_mod3)
Anova(tribin.imi_mod3)
Anova(tribin.kib_mod3)

#########

tribin.bolmm_mod1 <- glmer(as.formula(paste("BME ~ ",formula(tribin.bol_mod3),"+(1|site)")[3]), data=tribin.bolmm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)
tribin.endermm_mod1 <- glmer(as.formula(paste("BME ~ ",formula(tribin.ender_mod3),"+(1|site)")[3]), data=tribin.endermm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)
tribin.grahmm_mod1 <- glmer(as.formula(paste("BME ~ ",formula(tribin.grah_mod3),"+(1|site)")[3]), data=tribin.grahmm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)
tribin.imimm_mod1 <- glmer(as.formula(paste("BME ~ ",formula(tribin.imi_mod3),"+(1|site)")[3]), data=tribin.imimm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)
tribin.kibmm_mod1 <- glmer(as.formula(paste("BME ~ ",formula(tribin.kib_mod3),"+(1|site)")[3]), data=tribin.kibmm, family=binomial,control = glmerControl(optimizer = "bobyqa"),nAGQ = 10)

Anova(tribin.bolmm_mod1)
Anova(tribin.endermm_mod1)
Anova(tribin.grahmm_mod1)
Anova(tribin.imimm_mod1)
Anova(tribin.kibmm_mod1)

################################################################################
## test on the significance of the random effect
library(glmmML) ## http://www.diva-portal.org/smash/get/diva2:507527/FULLTEXT02
library(doParallel) ## to boost the computing speed
registerDoParallel(6) ## the calculation will be done on 6 processor cores to go faster. takes several minutes
bolmm_modML <- glmmML(formula(tribin.bol_mod3), data=tribin.bolmm, cluster=site, family=binomial(link="logit"),boot=10000)       # Bootstrap p= 0.7052
endermm_modML <- glmmML(formula(tribin.ender_mod3), data=tribin.endermm, cluster=site, family=binomial(link="logit"),boot=10000) # p= 0.7949
grahmm_modML <- glmmML(formula(tribin.grah_mod3), data=tribin.grahmm, cluster=site, family=binomial(link="logit"),boot=10000)    # p= 0.8029
imimm_modML <- glmmML(formula(tribin.imi_mod3), data=tribin.imimm, cluster=site, family=binomial(link="logit"),boot=10000)       # p= 0.6706
kibmm_modML <- glmmML(formula(tribin.kib_mod3), data=tribin.kibmm, cluster=site, family=binomial(link="logit"),boot=10000)       # p= 0.6853


################################################################################
## models accuracy AUC
library(pROC)

#### mixte effect models
auc(tribin.bolmm$BME, predict(tribin.bolmm_mod1,type="response")) ## 0.8862
auc(tribin.endermm$BME, predict(tribin.endermm_mod1,type="response")) ## 0.9492
auc(tribin.grahmm$BME, predict(tribin.grahmm_mod1,type="response")) ## 0.8841
auc(tribin.imimm$BME, predict(tribin.imimm_mod1,type="response")) ## 0.9315
auc(tribin.kibmm$BME, predict(tribin.kibmm_mod1,type="response")) ## 0.8995

#### models without random effect 
auc(tribin.bolmm$BME, predict(tribin.bol_mod3,type="response")) ## 0.8862
auc(tribin.endermm$BME, predict(tribin.ender_mod3,type="response")) ## 0.9492
auc(tribin.grahmm$BME, predict(tribin.grah_mod3,type="response")) ## 0.8841
auc(tribin.imimm$BME, predict(tribin.imi_mod3,type="response")) ## 0.9289
auc(tribin.kibmm$BME, predict(tribin.kib_mod3,type="response")) ## 0.8957

################################################################################
####### Internal validation LOOCV


library(foreach)
registerDoParallel(4)  ## the calculation will be performed on 4 processor cores
pred.bolmm<-foreach(i=1:nrow(tribin.bolmm), .combine="c")%do%
{
modloo<- glm(formula(tribin.bol_mod3),data=tribin.bolmm[-i,],family = binomial(link=logit))
predloo <-predict(modloo,tribin.bolmm[i,],type="response")
}
pred.endermm<-foreach(i=1:nrow(tribin.endermm), .combine="c")%do%
{
modloo<- glm(formula(tribin.ender_mod3),data=tribin.endermm[-i,],family = binomial(link=logit))
predloo <-predict(modloo,tribin.endermm[i,],type="response")
}
pred.grahmm<-foreach(i=1:nrow(tribin.grahmm), .combine="c")%do%
{
modloo<- glm(formula(tribin.grah_mod3),data=tribin.grahmm[-i,],family = binomial(link=logit))
predloo <-predict(modloo,tribin.grahmm[i,],type="response")
}
pred.imimm<-foreach(i=1:nrow(tribin.imimm), .combine="c")%do%
{
modloo<- glm(formula(tribin.imi_mod3),data=tribin.imimm[-i,],family = binomial(link=logit))
predloo <-predict(modloo,tribin.imimm[i,],type="response")
}
pred.kibmm<-foreach(i=1:nrow(tribin.kibmm), .combine="c")%do%
{
modloo<- glm(formula(tribin.kib_mod3),data=tribin.kibmm[-i,],family = binomial(link=logit))
predloo <-predict(modloo,tribin.kibmm[i,],type="response")
}

## accuracy
auc(tribin.bolmm$BME, pred.bolmm)## 0.8703
auc(tribin.endermm$BME, pred.endermm)## 0.9251
auc(tribin.grahmm$BME, pred.grahmm)## 0.8503
auc(tribin.imimm$BME, pred.imimm)## 0.9139
auc(tribin.kibmm$BME, pred.kibmm)## 0.8782


################################################################################
###### external validation

auc(bol.ve$BME, predict(tribin.bol_mod3,newdata=bol.ve,type="response")) ##  0.8362
auc(ender.ve$BME, predict(tribin.ender_mod3,newdata=ender.ve,type="response")) ##  0.8131
auc(grah.ve$BME, predict(tribin.grah_mod3,newdata=grah.ve,type="response")) ##  0.7428
auc(imi.ve$BME, predict(tribin.imi_mod3,newdata=imi.ve,type="response")) ##  0.8472
auc(kib.ve$BME, predict(tribin.kib_mod3,newdata=kib.ve,type="response")) ##  0.8361


################################################################################
####### prediction of presence

## training data
bol.ent$pred.BME.ent <- predict(tribin.bol_mod3,type="response") 
ender.ent$pred.BME.ent <- predict(tribin.ender_mod3,type="response") 
grah.ent$pred.BME.ent <- predict(tribin.grah_mod3,type="response") 
imi.ent$pred.BME.ent <- predict(tribin.imi_mod3,type="response") 
kib.ent$pred.BME.ent <- predict(tribin.kib_mod3,type="response") 

## internal validation data
bol.ent$pred.BME.vi <- pred.bolmm 
ender.ent$pred.BME.vi <- pred.endermm
grah.ent$pred.BME.vi <- pred.grahmm 
imi.ent$pred.BME.vi <- pred.imimm 
kib.ent$pred.BME.vi <- pred.kibmm 

## external validation data
bol.ve$pred.BME.ve <- predict(tribin.bol_mod3,newdata=bol.ve,type="response") 
ender.ve$pred.BME.ve <- predict(tribin.ender_mod3,newdata=ender.ve,type="response")
grah.ve$pred.BME.ve <- predict(tribin.grah_mod3,newdata=grah.ve,type="response") 
imi.ve$pred.BME.ve <- predict(tribin.imi_mod3,newdata=imi.ve,type="response") 
kib.ve$pred.BME.ve <- predict(tribin.kib_mod3,newdata=kib.ve,type="response") 


## save these modified data.frame

################################################################################
###### odd ratio
## first step: reorder factor levels

# bolitinos : t_min_interP_qt4 
tribin.bolmm$t_min_interP_qt4<-factor(tribin.bolmm$t_min_interP_qt4,levels=c("[-Inf,7.04]","(7.04,13.7]","(13.7,16.9]","(16.9, Inf]"))
levels(tribin.bolmm$t_min_interP_qt4)

# enderleini: pluie_recup_qt5 
tribin.endermm$pluie_recup_qt5<-factor(tribin.endermm$pluie_recup_qt5,levels=c("[-Inf,0.1]","(0.1,1.1]","(1.1,6.3]","(6.3, Inf]"))
levels(tribin.endermm$pluie_recup_qt5)

# grah: daupi dj dans l'ordre, t_minP_qt5
tribin.grahmm$t_minP_qt5<-factor(tribin.grahmm$t_minP_qt5,levels=c("[-Inf,12.1]","(12.1,15.1]","(15.1,18]","(18,21]","(21, Inf]"))
levels(tribin.grahmm$t_minP_qt5)

# imi: daupi ok

# kib: daupi; pluie_pos_qt5; pluie_recup_qt5 
tribin.kibmm$daupi<-factor(tribin.kibmm$daupi,levels=c("fss&savane","fhb","fhmce","fhmco","ft"))
levels(tribin.kibmm$daupi)


tribin.bol_mod3 <- glm(formula(tribin.bol_mod3), data=tribin.bolmm, family=binomial(link="logit"))
tribin.ender_mod3 <- glm(formula(tribin.ender_mod3), data=tribin.endermm, family=binomial(link="logit"))
tribin.grah_mod3 <- glm(formula(tribin.grah_mod3), data=tribin.grahmm, family=binomial(link="logit"))
tribin.imi_mod3 <- glm(formula(tribin.imi_mod3), data=tribin.imimm, family=binomial(link="logit"))
tribin.kib_mod3 <- glm(formula(tribin.kib_mod3), data=tribin.kibmm, family=binomial(link="logit"))

## save th models


###### odd ratio
library(epicalc)
logistic.display(tribin.bol_mod3)
logistic.display(tribin.ender_mod3)
logistic.display(tribin.grah_mod3)
logistic.display(tribin.imi_mod3)
logistic.display(tribin.kib_mod3)

## visualize the effect of the variable
library(effects)

plot(allEffects(tribin.bol_mod3))
plot(allEffects(tribin.ender_mod3))
plot(allEffects(tribin.grah_mod3))
plot(allEffects(tribin.imi_mod3))
plot(allEffects(tribin.kib_mod3))


