

################################################################################
######## collinearity analysis on mean model (glm) ############################

############ Note: when entering all variables, some coefficients appear in NA
############ Step 1: remove all variables with NA coeff
############ determine all colinear variables (vif function)
############ integrate the NA coefficient variables 1 to 1 and check the variance inflation

tribin.bol_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_bolmm, collapse= "+"))), data=tribin.bolmm, family=binomial(link="logit"))
tribin.ender_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_endermm, collapse= "+"))), data=tribin.endermm, family=binomial(link="logit"))
tribin.grah_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_grahmm, collapse= "+"))), data=tribin.grahmm, family=binomial(link="logit"))
tribin.imi_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_imimm, collapse= "+"))), data=tribin.imimm, family=binomial(link="logit"))
tribin.kib_mod0 <- glm(as.formula(paste("BME ~ ", paste(good_kibmm, collapse= "+"))), data=tribin.kibmm, family=binomial(link="logit"))

### variables with NA coeff
bad_bolmm <- c("plant_forest0.5","plant_forest1","plant_forest2","prairie0.5","tot_anx0.5","tot_anx1","verger0.5","verger1","verger2")
bad_endermm <-c("hydro0.5","hydro1","hydro2","nbsite2","plant_forest2","prairie0.5","prairie1","prairie2","roche_nue1","roche_nue2","tot_anx2",
            "verger0.5","verger1","verger2","zone_urb0.5","zone_urb1","zone_urb2")
bad_grahmm <-c("autre1","foret2","hydro0.5","hydro1","hydro2","nbsite2","petit_ru0.5","prairie0.5","prairie1","prairie2","roche_nue1",
           "roche_nue2","savane1","savane2","verger0.5","verger1","zone_urb0.5","zone_urb1")
bad_imimm <-c("nbsite2","ouv_bat","petit_ru1","plant_forest0.5","plant_forest1","plant_forest2","prairie0.5","prairie1","prairie2",
          "roche_nue1","roche_nue2","savane0.5","savane1","savane2","tot_anx0.5","tot_anx1","tot_anx2","verger0.5","verger1",
          "verger2","zone_urb0.5","zone_urb1","zone_urb2") 
bad_kibmm <-c("foret2","hydro0.5","hydro1","hydro2","petit_ru0.5","plant_forest1","plant_forest2","prairie0.5","prairie1","prairie2",
          "roche_nue1","roche_nue2","verger0.5","verger1","verger2","zone_urb0.5","zone_urb1","zone_urb2")


### variance inflation analysis
library(epicalc)

tribin.bol_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_bolmm[!good_bolmm %in% bad_bolmm], collapse= "+"))), data=tribin.bolmm, family=binomial(link="logit"))
tribin.ender_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_endermm[!good_endermm %in% bad_endermm], collapse= "+"))), data=tribin.endermm, family=binomial(link="logit"))
tribin.grah_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_grahmm[!good_grahmm %in% bad_grahmm], collapse= "+"))), data=tribin.grahmm, family=binomial(link="logit"))
tribin.imi_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_imimm[!good_imimm %in% bad_imimm], collapse= "+"))), data=tribin.imimm, family=binomial(link="logit"))
tribin.kib_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_kibmm[!good_kibmm %in% bad_kibmm], collapse= "+"))), data=tribin.kibmm, family=binomial(link="logit"))

#### bolitinos
## step 1: use vif(tribin.bol_mod1)
## Step 2: add in vif.bol and vif.bol2 the variable with the highest GVIF
## Step 3: update tribin.bol_mod1 so that the function contains the right variable names.
## Step 4: repeat steps 2 and 3 until all GVIFs are less than 2
## Step 5: include one by one the variables present in bad_bolmm, keeping those that do not increase collinearity
## when a strong GVIF concerns a variable that was not present in bad_bolmm, vif.bol2 is incremented

vif.bol<- c("cult_maraich1","t_moy","bov0.5","logtmoy_3.2","cult_maraich2","tminP_2.1","tmoy_21","bov1","t_minP","petit_ru1")
# vif.bol2<- c("cult_maraich1","t_moy","bov0.5","logtmoy_3.2","cult_maraich2","bov1","tminP_2.1","tmoy_21","t_minP","petit_ru1","nbsite2")
vif.bol3<-c(bad_bolmm[-c(1)],vif.bol)
tribin.bol_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_bolmm[!good_bolmm %in% c(bad_bolmm[-c(1)],vif.bol)], collapse= "+"))), data=tribin.bolmm, family=binomial(link="logit"))
vif(tribin.bol_mod1)
#
logistic.display(tribin.bol_mod1) ## to verify the IC95 of the OR

#### enderleini
vif.ender<- c("canne1","canne0.5","foret1","tmoy_50.0","logtminP30d_28.1","bov2","t_moy","tmoy30d_12.10","logtmoy30d_30.0","canne2","tminP_49.0","t_minP","foret0.5","vent_recup","tminP30d_11.10")
vif.ender2<- c("canne1","canne0.5","foret1","tmoy_50.0","logtminP30d_28.1","bov2","t_moy","tmoy30d_12.10","logtmoy30d_30.0","canne2","tminP_49.0","t_minP","foret0.5","vent_recup","tminP30d_11.10","t_min_interP","tmaxP_16.10")
vif.ender3<-c(bad_endermm[-c(4,7,14)],vif.ender2)
tribin.ender_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_endermm[!good_endermm %in% c(bad_endermm[-c(4,7,14)],vif.ender2)], collapse= "+"))), data=tribin.endermm, family=binomial(link="logit"))
vif(tribin.ender_mod1)

logistic.display(tribin.ender_mod1)

#### grahamii
vif.grah<- c("canne1","canne0.5","foret1","canne2","foret0.5","tminP_2")
#vif.grah2<- c("canne1","canne0.5","foret1","canne2","foret0.5")
vif.grah3<-c(bad_grahmm[-c(12,16)],vif.grah)
tribin.grah_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_grahmm[!good_grahmm %in% c(bad_grahmm[-c(12,16)],vif.grah)], collapse= "+"))), data=tribin.grahmm, family=binomial(link="logit"))
vif(tribin.grah_mod1)

logistic.display(tribin.grah_mod1)

#### imicola
vif.imi<- c("bov2","tminP_50.4","tmoy_45.27","bov1","t_moy","logtmoy30d_10.4","logtmoy_43.33","nbsite0.5","tmaxP_5.0","tminP30d_10.4","logtmaxP_48.0","nbsite1","logtminP30d_28.4","foret2","t_minP","tmoy30d_5","t_min_interP")
vif.imi2<- c("bov2","tminP_50.4","tmoy_45.27","bov1","t_moy","logtmoy30d_10.4","logtmoy_43.33","nbsite0.5","tmaxP_5.0","tminP30d_10.4","logtminP30d_28.4","logtmaxP_48.0","nbsite1","foret2","t_minP","tmoy30d_5","t_min_interP","hydro2","logtminP_39.33")
vif.imi3<- c(bad_imimm[-c(2,3,23)],vif.imi2)
tribin.imi_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_imimm[!good_imimm %in% c(bad_imimm[-c(2,3,23)],vif.imi2)], collapse= "+"))), data=tribin.imimm, family=binomial(link="logit"))
vif(tribin.imi_mod1)

logistic.display(tribin.imi_mod1)

#### kibatiensis
vif.kib<- c("canne0.5","canne1","canne2","t_moy","foret1","tmoy_2","tminP_2.1","hr30d_25.4","logtmoy_5","foret0.5","t_minP","t_min_interP","tmaxP_16.11")
#vif.kib2<- c("canne1","canne0.5","foret1","t_moy","tminP_2.0","canne2","tmoy_5","logtmaxP_5.3","foret2","t_minP","t_min_interP","vent_recup","t_maxP","foret0.5","logtminP_5.4","hydro0.5")
vif.kib3 <- c(bad_kibmm[-c(12,18)],vif.kib)
tribin.kib_mod1 <- glm(as.formula(paste("BME ~ ", paste(good_kibmm[!good_kibmm %in% c(bad_kibmm[-c(12,18)],vif.kib)], collapse= "+"))), data=tribin.kibmm, family=binomial(link="logit"))
vif(tribin.kib_mod1)

logistic.display(tribin.kib_mod1)

########################################
                                         
              