################################################################################
############  IMPORT DATA #############
################################################################################

setwd("D:/boulot/Y.G/cullicodes/suivi longitudinal 2.0/model an2")
bol_tt3     <-read.table("bol_tt3.txt",header=T)  
ender_tt3   <-read.table("ender_tt3.txt",header=T)
grah_tt3    <-read.table("grah_tt3.txt",header=T)
imi_tt3     <-read.table("imi_tt3.txt",header=T)
kib_tt3     <-read.table("kib_tt3.txt",header=T)

bol.ent     <-read.table("bol.ent.txt",header=T)  
ender.ent   <-read.table("ender.ent.txt",header=T)
grah.ent    <-read.table("grah.ent.txt",header=T)
imi.ent     <-read.table("imi.ent.txt",header=T)
kib.ent     <-read.table("kib.ent.txt",header=T)

## useful variables
bol.zt  <- bol.ent[bol.ent$nombre > 0 ,c(1,5,10:70,72:123,138:155)]
ender.zt<- ender.ent[ender.ent$nombre > 0 ,c(1,5,10:70,72:123,144:157)]
grah.zt <- grah.ent[grah.ent$nombre > 0 ,c(1,5,10:70,72:123,142:155)]
imi.zt  <- imi.ent[imi.ent$nombre > 0 ,c(1,5,10:70,72:123,145:165)]
kib.zt  <- kib.ent[kib.ent$nombre > 0 ,c(1,5,10:70,72:123,138:158)]

################################################################################
### variable list

### bolitinos
nom.bol.zt<-names(bol.zt)[c(3:length(names(bol.zt)))]
nom.bol.tmp<-nom.bol.zt#[!nom.bol.zt %in% c("plant_forest0.5")]

### enderleini
nom.ender.zt<-names(ender.zt)[c(3:length(names(ender.zt)))]
nom.ender.tmp<-nom.ender.zt#[!nom.ender.zt %in% c("autre0.5","autre1","plant_forest2","plant_forest1","plant_forest0.5")]
                                                                       
### grahamii
nom.grah.zt<-names(grah.zt)[c(3:length(names(grah.zt)))]
nom.grah.tmp<-nom.grah.zt
                                                                                                                                                                                   
### imicola
nom.imi.zt<-names(imi.zt)[c(3:length(names(imi.zt)))]
nom.imi.tmp<-nom.imi.zt

### kibatiensis
nom.kib.zt<-names(kib.zt)[c(3:length(names(kib.zt)))] 
nom.kib.tmp<-nom.kib.zt

################################################################################
########### univariate analysis ################################################
################################################################################
library(doParallel) ## boost computation speed
library(foreach)


### package glmmTMB
library(glmmTMB)
truncated_nbinom2(link = "log")
lien<-"log"
trnb<-"truncated_nbinom2"  ## variance=mu*(1+mu/phi) 
                           ## variance increases quadratically with the mean (Hardin & Hilbe 2007)

registerDoParallel(4)

mod_tmpbol<-lapply(nom.bol.tmp, function(x) eval(parse(text=paste( "glmmTMB(nombre ~",x,"+(1|site), data = bol.zt, family=truncated_nbinom2(link=lien))"))))
mod_tmpender<-lapply(nom.ender.tmp, function(x) eval(parse(text=paste( "glmmTMB(nombre ~",x,"+(1|site), data = ender.zt, family=truncated_nbinom2(link=lien))"))))
mod_tmpgrah<-lapply(nom.grah.tmp, function(x) eval(parse(text=paste( "glmmTMB(nombre ~",x,"+(1|site), data = grah.zt, family=truncated_nbinom2(link=lien))"))))

mod_tmpimi<-lapply(nom.imi.tmp, function(x) eval(parse(text=paste( "glmmTMB(nombre ~",x,"+(1|site), data = imi.zt, family=truncated_nbinom2(link=lien))"))))
mod_tmpkib<-lapply(nom.kib.tmp, function(x) eval(parse(text=paste( "glmmTMB(nombre ~",x,"+(1|site), data = kib.zt, family=truncated_nbinom2(link=lien))"))))

## save all models
## save(file="mod_tmpbol2",mod_tmpbol)      
## load("mod_tmpbol2")      

names(mod_tmpbol)=nom.bol.tmp
names(mod_tmpender)=nom.ender.tmp
names(mod_tmpgrah)=nom.grah.tmp
names(mod_tmpimi)=nom.imi.tmp
names(mod_tmpkib)=nom.kib.tmp

################################################################################
####### variable selection

#### to be able to perform the univariate analysis, we need an Anova function adapted to the model
#### cf. step 3.1 Anova glmmTMB
#### open the file and read all the code

## https://github.com/glmmTMB/glmmTMB/blob/master/glmmTMB/R/Anova.R
ano_tmpbol<-lapply(mod_tmpbol, function(x) Anova.II.glmmTMB(x))      
ano_tmpender<-lapply(mod_tmpender, function(x) Anova.II.glmmTMB(x))       
ano_tmpgrah<-lapply(mod_tmpgrah, function(x) Anova.II.glmmTMB(x))
ano_tmpimi<-lapply(mod_tmpimi, function(x) Anova.II.glmmTMB(x))      
ano_tmpkib<-lapply(mod_tmpkib, function(x) Anova.II.glmmTMB(x))       


### variable selection p<0.2

sortie.tmpbol<-sapply(ano_tmpbol,function(x) x$Pr)
sortie.tmpender<-sapply(ano_tmpender,function(x) x$Pr)
sortie.tmpgrah<-sapply(ano_tmpgrah,function(x) x$Pr)
sortie.tmpimi<-sapply(ano_tmpimi,function(x) x$Pr)
sortie.tmpkib<-sapply(ano_tmpkib,function(x) x$Pr)

tri.tmpbol<-(sortie.tmpbol)[sortie.tmpbol<0.2]
tri.tmpender<-(sortie.tmpender)[sortie.tmpender<0.2]
tri.tmpgrah<-(sortie.tmpgrah)[sortie.tmpgrah<0.2]
tri.tmpimi<-(sortie.tmpimi)[sortie.tmpimi<0.2]
tri.tmpkib<-(sortie.tmpkib)[sortie.tmpkib<0.2]


## names(tri.trnb)
#### visualization barplot for elimination of duplicate variables: numerical > quantile qt5 ... quantile qt3 > log10
par(mai=c(2,1,1,1))

barplot(tri.tmpbol[sort(names(tri.tmpbol))],las=2,cex.lab=0.8,main = "bolitinos TMP2")  
barplot(tri.tmpender[sort(names(tri.tmpender))],las=2,cex.lab=0.8,main = "enderleini TMP2")
barplot(tri.tmpgrah[sort(names(tri.tmpgrah))],las=2,cex.lab=0.8,main = "grahamii TMP2")

barplot(tri.tmpimi[sort(names(tri.tmpimi))],las=2,cex.lab=0.8,main = "imicola TMP2")  
barplot(tri.tmpkib[sort(names(tri.tmpkib))],las=2,cex.lab=0.8,main = "kibatiensis TMP2")
barplot(tri.tmpimiPLx[sort(names(tri.tmpimiPLx))],las=2,cex.lab=0.8,main = "imicola hors PL02 TMP2")

################################################################################
######## list of selected variables ##########################
good_bolTMB.zt<-c("anx_cible","autre0.5","autre1","autre2","bov0.5","bov1","cult_maraich0.5","cult_maraich1","cult_maraich2",
              "foret1","foret2","hydro0.5","hydro1","hydro2","nbsite2","ndvi_est","ouv_bat","petit_ru1","plant_forest1",
              "plant_forest2","pluie_pos_qt5","pluie_recup_log10","prairie0.5","rg_pos_qt4","rg_recup_qt3","savane0.5","t_max_interP",
              "t_maxP","t_minP","t_moy","tot_anx0.5","tot_anx1","vent_pos","vent_recup","verger0.5","verger1","verger2",
              "zone_urb0.5","zone_urb1","zone_urb2","zt.hr_9.8","zt.log_pluie_25.23","zt.logndvi_est_5.0","zt.logtminP30d_10",
              "zt.ndvi_est_4.3","zt.pluie_9","zt.tmaxP_35","zt.tmaxP30d_22.21","zt.tminP_41","zt.tminP30d_25","zt.tmoy_42",
              "zt.tmoy30d_25")

good_enderTMB.zt<-c("anx_cible","bov0.5","canne2","daupi","foret0.5","foret1","foret2","hydro0.5","hydro1","hydro2",
                "ndvi_est","petit_ru0.5","petit_ru1","roche_nue1","roche_nue2","t_maxP_qt5","t_min_interP_log10",
                "t_moy_qt4","tot_anx0.5","tot_anx1","vent_pos_qt4","vent_recup_qt5","zt.log_pluie_9","zt.ndvi_est_50","zt.ndvi_est30d_4",
                "zt.pluie_9","zt.tmaxP_28.19","zt.tminP_14.13","zt.tmoy_15" )

good_grahTMB.zt<-c("autre2","canne0.5","canne1","canne2","daupi","foret0.5","foret1","foret2","hr","hydro0.5","hydro1","hydro2",
               "nbsite0.5","nbsite1","ndvi_est_qt5","ouv_bat","petit_ru1","petit_ru2","plant_forest2","pluie_pos_qt5","pluie_recup_qt5",
               "prairie0.5","prairie1","prairie2","rg_pos_qt5","rg_recup_qt5","roche_nue0.5","t_max_interP","t_maxP","t_min_interP",
               "t_minP","t_moy","vent_pos_qt5","verger0.5","verger1","verger2","zone_urb0.5","zt.hr_23",
               "zt.ndvi_est_21","zt.pluie_6.5","zt.tmaxP30d_8.7","zt.tminP_15","zt.tmoy_15")

good_imiTMB.zt<-c("autre2","bov0.5","bov1","bov2","canne2","daupi","foret1","foret2","hr","hydro0.5","hydro1","hydro2","nbsite0.5",
              "nbsite1","nbsite2","ndvi_est_qt5","ouv_bat","petit_ru1","petit_ru2","plant_forest1","plant_forest2","pluie_pos_qt5",
              "pluie_recup","prairie0.5","prairie1","prairie2","rg_pos","rg_recup","roche_nue1","roche_nue2","savane0.5","savane1",
              "savane2","t_max_interP","t_maxP","t_min_interP","t_minP","t_moy","tot_anx2","vent_pos","vent_recup_qt5","verger2",
              "zone_urb0.5","zone_urb1","zone_urb2","zt.hr_50.32","zt.hr30d_26","zt.logtmoy_33.31","zt.logtmoy30d_26.22",
              "zt.ndvi_est_50","zt.pluie_50.0","zt.pluie30d_27.0","zt.tmaxP_32.1","zt.tmaxP30d_26.1","zt.tminP_24.22","zt.tmoy_26")

good_kibTMB.zt<-c("autre0.5","autre1","autre2","canne0.5","canne1","canne2","daupi","foret0.5","foret1","foret2","hr","hydro0.5",
              "hydro1","hydro2","plant_forest0.5","plant_forest2","pluie_pos_qt5","prairie0.5","prairie1","prairie2","rg_pos",
              "rg_recup","roche_nue1","roche_nue2","savane1","savane2","t_maxP","t_min_interP","t_minP_qt5","t_moy_qt5",
              "verger0.5","verger1","verger2","zone_urb0.5","zone_urb1","zone_urb2","zt.tmaxP_44","zt.tminP_46")

################################################################################
########################## multivariate modele #################################
################################################################################

########## collinearity analysis and backward AIC selection
########## cf. step 3.2: variance inflated and backward AIC

########## best modle

best_bol.TMB<-c("bov1","ouv_bat","plant_forest1","pluie_pos_qt5","pluie_recup_log10","rg_pos_qt4","rg_recup_qt3","savane0.5","zt.log_pluie_25.23","zt.logtminP30d_10","zt.pluie_9","zt.tmaxP_35")
best_ender.TMB<-c("daupi","petit_ru1","t_min_interP_log10","tot_anx1","vent_recup_qt5","zt.log_pluie_9")
best_grah.TMB<-c("daupi","ouv_bat","pluie_pos_qt5","pluie_recup_qt5","rg_pos_qt5","zt.ndvi_est_21")  ##  "nbsite0.5"
best_imi.TMB<-c("autre2","daupi","ndvi_est_qt5","plant_forest1","pluie_pos_qt5","pluie_recup","roche_nue2","t_max_interP","t_maxP","zt.hr30d_26","zt.ndvi_est_50") 
best_kib.TMB<-c("autre0.5","autre2","daupi","pluie_pos_qt5","rg_recup","t_min_interP","t_minP_qt5","zt.tmaxP_44") ## "hr" 

################################################################################
########## multivariate analysis
########## ordination des levels des variables factorielles pour les 2 types de modles

### 
bolTMB0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_bol.TMB, collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
enderTMB0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_ender.TMB, collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
grahTMB0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_grah.TMB, collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
imiTMB0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_imi.TMB, collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
kibTMB0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_kib.TMB, collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))


########################################## ordering of factor levels 

## bolitinos   ""ouv_bat","pluie_pos_qt5","rg_pos_qt4","rg_recup_qt3"
levels(bol.zt$ouv_bat) ## ok

levels(bol.zt$pluie_pos_qt5)
bol.zt$pluie_pos_qt5<-factor(bol.zt$pluie_pos_qt5,levels=c("[-Inf,0.2]","(0.2,1.5]","(1.5,6.92]","(6.92, Inf]"))
levels(bol.zt$rg_pos_qt4)
bol.zt$rg_pos_qt4<-factor(bol.zt$rg_pos_qt4,levels=c("[-Inf,1.09]","(1.09,1.53]","(1.53,1.97]","(1.97, Inf]"))
levels(bol.zt$rg_recup_qt3)
bol.zt$rg_recup_qt3<-factor(bol.zt$rg_recup_qt3,levels=c("[-Inf,1.25]","(1.25,1.8]","(1.8, Inf]"))

## enderleini   "daupi","vent_recup_qt5"
levels(ender.zt$daupi)
ender.zt$daupi<-factor(ender.zt$daupi,levels=c("fss&savane","fhb","fhm&ft"))
levels(ender.zt$vent_recup_qt5)
ender.zt$vent_recup_qt5<-factor(ender.zt$vent_recup_qt5,levels=c("[-Inf,0.512]","(0.512,0.9]","(0.9,1.2]","(1.2,1.46]","(1.46, Inf]"))

## grahamii    "daupi","ouv_bat","pluie_pos_qt5","pluie_recup_qt5","rg_pos_qt5"

levels(grah.zt$daupi)

levels(grah.zt$pluie_pos_qt5)
grah.zt$pluie_pos_qt5<-factor(grah.zt$pluie_pos_qt5,levels=c("[-Inf,0.2]","(0.2,1.5]","(1.5,6.92]","(6.92, Inf]"))

levels(grah.zt$pluie_recup_qt5)
grah.zt$pluie_recup_qt5<-factor(grah.zt$pluie_recup_qt5,levels=c("[-Inf,0.1]","(0.1,1.1]","(1.1,6.3]","(6.3, Inf]"))

levels(grah.zt$rg_pos_qt5)
grah.zt$rg_pos_qt5<-factor(grah.zt$rg_pos_qt5,levels=c("[-Inf,1.01]","(1.01,1.38]","(1.38,1.68]","(1.68,2.1]","(2.1, Inf]"))


## imicola  "daupi","ndvi_est_qt5","pluie_pos_qt5"

levels(imi.zt$daupi)
imi.zt$daupi<-factor(imi.zt$daupi,levels=c("fhb","fss&savane","fhmce","fhmco&ft"))
levels(imi.zt$ndvi_est_qt5)
imi.zt$ndvi_est_qt5<-factor(imi.zt$ndvi_est_qt5,levels=c("[-Inf,60]","(73,78]","(60,67]","(67,73]","(78, Inf]"))
levels(imi.zt$pluie_pos_qt5)
imi.zt$pluie_pos_qt5<-factor(imi.zt$pluie_pos_qt5,levels=c("[-Inf,0.2]","(0.2,1.5]","(1.5,6.92]","(6.92, Inf]"))

## kibatiensis    "daupi","pluie_pos_qt5" , ,"t_minP_qt5"
levels(kib.zt$daupi)
kib.zt$daupi<-factor(kib.zt$daupi,levels=c("ft","fss&savane","fhb","fhmco","fhmce"))

levels(kib.zt$pluie_pos_qt5)
kib.zt$pluie_pos_qt5<-factor(kib.zt$pluie_pos_qt5,levels=c( "[-Inf,0.2]","(0.2,1.5]","(1.5,6.92]","(6.92, Inf]"))

levels(kib.zt$t_minP_qt5)
kib.zt$t_minP_qt5<-factor(kib.zt$t_minP_qt5,levels=c("(18,21]","[-Inf,12.1]","(12.1,15.1]","(15.1,18]","(21, Inf]"))


## les modles

bolTMB <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_bol.TMB, collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
enderTMB <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_ender.TMB, collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
grahTMB <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_grah.TMB, collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
imiTMB <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_imi.TMB, collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
kibTMB <- glmmTMB(as.formula(paste("nombre ~ ", paste(best_kib.TMB, collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))

####### save

##################################################
## incidence rate ratio
exp(fixef(bolTMB)$cond)
## or
exp(confint(bolTMB))




