################################################################################
######## 

library(usdm)
library(car)
library(bbmle)


bolTMB.zt3<-bol.zt[,good_bolTMB.zt]
enderTMB.zt3<-ender.zt[,good_enderTMB.zt]
grahTMB.zt3<-grah.zt[,good_grahTMB.zt]
imiTMB.zt3<-imi.zt[,good_imiTMB.zt]
kibTMB.zt3<-kib.zt[,good_kibTMB.zt]

################################################################################
######## collinearity analysis on mean negative binomial model (glm) ############################

############ Note: when entering all variables, some coefficients appear in NA
############ Step 1: remove all variables with NA coeff (ex: bad_bolx)
############ determine all colinear variables (vif function; car package)
############ integrate the NA coefficient variables 1 to 1 and check the variance inflation

## step 1: use car::vif(bolx)
## Step 2: add in vif.bolx and vif.bolx2 the variable with the highest GVIF
## Step 3: update goodvif.bolTMP and bolx so that the function contains the right variable names.
## Step 4: repeat steps 2 and 3 until all GVIFs are less than 2
## Step 5: include one by one the variables present in bad_bolx, keeping those that do not increase collinearity
## when a strong GVIF concerns a variable that was not present in bad_bolx, vif.bolx2 is incremented

library(MASS)                                                              

################################################################################
########  Vif par mthode glm gaussien

bolx <- glm(as.formula(paste("nombre ~ ", paste(good_bolTMB.zt, collapse= "+"))), data=bol.zt)
bad.bolx<-c("autre1","hydro0.5","hydro1","hydro2","nbsite2","ouv_bat","petit_ru1","plant_forest1","plant_forest2","prairie0.5","savane0.5","tot_anx0.5","tot_anx1","verger0.5","verger1","verger2","zone_urb0.5","zone_urb1","zone_urb2")
bolx <- glm(as.formula(paste("nombre ~ ", paste(good_bolTMB.zt[!good_bolTMB.zt %in% bad.bolx], collapse= "+"))), data=bol.zt)
vif.bolx<-c("cult_maraich2","foret1","bov0.5","t_moy","zt.logndvi_est_5.0","ndvi_est","zt.tmoy30d_25","cult_maraich1","zt.tmoy_42","t_minP","zt.tminP30d_25","zt.tmaxP30d_22.21","vent_pos","zt.tminP_41","t_maxP")
vif.bolx2<-c("cult_maraich2","foret1","bov0.5","t_moy","zt.logndvi_est_5.0","ndvi_est","zt.tmoy30d_25","cult_maraich1","zt.tmoy_42","t_minP","zt.tminP30d_25","zt.tmaxP30d_22.21","vent_pos","zt.tminP_41","t_maxP","cult_maraich0.5","autre2","anx_cible","foret2")
#goodvif.bolTMP2<-good_bolTMB.zt[!good_bolTMB.zt %in% c(bad.bolx[-c(6,7,8,11)],vif.bolx2)]
bolx <- glm(as.formula(paste("nombre ~ ", paste(good_bolTMB.zt[!good_bolTMB.zt %in% c(bad.bolx[-c(6,7,8,11)],vif.bolx2)], collapse= "+"))), data=bol.zt)
car::vif(bolx)
confint(bolx)

goodvif.bolTMP2<- c("bov1","autre0.5","ouv_bat","petit_ru1","plant_forest1","pluie_pos_qt5","pluie_recup_log10","rg_pos_qt4","rg_recup_qt3","savane0.5","t_max_interP","vent_recup","zt.hr_9.8","zt.log_pluie_25.23","zt.logtminP30d_10","zt.ndvi_est_4.3","zt.pluie_9","zt.tmaxP_35")


enderx <- glm(as.formula(paste("nombre ~ ", paste(good_enderTMB.zt, collapse= "+"))), data=ender.zt)
bad.enderx<-c("foret1","foret2","hydro0.5","hydro1","hydro2","petit_ru0.5","petit_ru1","roche_nue1","roche_nue2","tot_anx0.5","tot_anx1")
enderx <- glm(as.formula(paste("nombre ~ ", paste(good_enderTMB.zt[!good_enderTMB.zt %in% bad.enderx], collapse= "+"))), data=ender.zt)
vif.enderx<-c("anx_cible","zt.ndvi_est30d_4","foret0.5","zt.tminP_14.13","canne2","zt.pluie_9","t_moy_qt4","zt.tmaxP_28.19")
vif.enderx2<-c("anx_cible","zt.ndvi_est30d_4","foret0.5","zt.tminP_14.13","canne2","zt.pluie_9","t_moy_qt4","zt.tmaxP_28.19","bov0.5")
enderx <- glm(as.formula(paste("nombre ~ ", paste(good_enderTMB.zt[!good_enderTMB.zt %in% c(bad.enderx[-c(7,11)],vif.enderx2)], collapse= "+"))), data=ender.zt)
car::vif(enderx)
exp(confint(enderx))

goodvif.enderTMP2<- c("daupi","ndvi_est","petit_ru1","t_maxP_qt5","t_min_interP_log10","tot_anx1","vent_pos_qt4","vent_recup_qt5","zt.log_pluie_9","zt.ndvi_est_50","zt.tmoy_15")

grahx <- glm(as.formula(paste("nombre ~ ", paste(good_grahTMB.zt, collapse= "+"))), data=grah.zt)
bad.grahx<-c("hydro0.5","hydro1","hydro2","nbsite0.5","nbsite1","ouv_bat","petit_ru1","petit_ru2","plant_forest2","prairie0.5","prairie1","prairie2","roche_nue0.5","verger0.5","verger1","verger2","zone_urb0.5")
grahx <- glm(as.formula(paste("nombre ~ ", paste(good_grahTMB.zt[!good_grahTMB.zt %in% bad.grahx], collapse= "+"))), data=grah.zt)
vif.grahx<-c("canne1","canne0.5","t_moy","foret2","canne2","zt.tmoy_15","foret1","foret0.5","t_minP","zt.tmaxP30d_8.7","hr")
vif.grahx2<-c("canne1","canne0.5","t_moy","foret2","canne2","zt.tmoy_15","foret1","foret0.5","t_minP","zt.tmaxP30d_8.7","hr","autre2","t_min_interP","zt.tminP_15")  ## [-c(4,6)]
grahx <- glm(as.formula(paste("nombre ~ ", paste(good_grahTMB.zt[!good_grahTMB.zt %in% c(bad.grahx[-c(4,6)],vif.grahx2)], collapse= "+"))), data=grah.zt)
car::vif(grahx)
confint(grahx)

goodvif.grahTMP2<- c("daupi","nbsite0.5","ndvi_est_qt5","ouv_bat","pluie_pos_qt5","pluie_recup_qt5","rg_pos_qt5","rg_recup_qt5","t_max_interP","t_maxP","vent_pos_qt5","zt.hr_23","zt.ndvi_est_21","zt.pluie_6.5")


imix <- glm(as.formula(paste("nombre ~ ", paste(good_imiTMB.zt, collapse= "+"))), data=imi.zt)
bad.imix<-c("hydro0.5","hydro1","hydro2","nbsite0.5","nbsite1","nbsite2","ouv_bat","petit_ru1","petit_ru2","plant_forest1","plant_forest2","prairie0.5","prairie1","prairie2","roche_nue1","roche_nue2","savane0.5","savane1","savane2","tot_anx2","verger2","zone_urb0.5","zone_urb1","zone_urb2")
imix <- glm(as.formula(paste("nombre ~ ", paste(good_imiTMB.zt[!good_imiTMB.zt %in% bad.imix], collapse= "+"))), data=imi.zt)
vif.imix<-c("foret2","zt.tmaxP_32.1","bov2","t_moy","zt.logtmoy30d_26.22","foret1","zt.tmaxP30d_26.1","zt.tminP_24.22","zt.tmoy_26","canne2","t_minP","zt.pluie_50.0","bov1","zt.logtmoy_33.31","rg_pos")
vif.imix2<-c("foret2","zt.tmaxP_32.1","bov2","t_moy","zt.logtmoy30d_26.22","foret1","zt.tmaxP30d_26.1","zt.tminP_24.22","zt.tmoy_26","canne2","t_minP","zt.pluie_50.0","bov1","zt.logtmoy_33.31","rg_pos","t_min_interP","bov0.5") ##  [-c(5,8,10,16)]
imix <- glm(as.formula(paste("nombre ~ ", paste(good_imiTMB.zt[!good_imiTMB.zt %in% c(bad.imix[-c(5,8,10,16)],vif.imix2)], collapse= "+"))), data=imi.zt)
car::vif(imix)
exp(confint(imix))

goodvif.imiTMP2<- c("autre2","daupi","hr","nbsite1","ndvi_est_qt5","petit_ru1","plant_forest1","pluie_pos_qt5","pluie_recup","rg_recup","roche_nue2","t_max_interP","t_maxP","vent_pos","vent_recup_qt5","zt.hr_50.32","zt.hr30d_26","zt.ndvi_est_50","zt.pluie30d_27.0")

kibx <- glm(as.formula(paste("nombre ~ ", paste(good_kibTMB.zt, collapse= "+"))), data=kib.zt)
bad.kibx<-c("autre1","foret1","foret2","hydro0.5","hydro1","hydro2","plant_forest0.5","plant_forest2","prairie0.5","prairie1","prairie2","roche_nue1","roche_nue2","savane1","savane2","verger0.5","verger1","verger2","zone_urb0.5","zone_urb1","zone_urb2")
kibx <- glm(as.formula(paste("nombre ~ ", paste(good_kibTMB.zt[!good_kibTMB.zt %in% bad.kibx], collapse= "+"))), data=kib.zt)
vif.kibx<-c("canne1","canne0.5","foret0.5","canne2","t_maxP")
vif.kibx2<-c("canne1","canne0.5","foret0.5","canne2","t_maxP") ## [-c(13)]
kibx <- glm(as.formula(paste("nombre ~ ", paste(good_kibTMB.zt[!good_kibTMB.zt %in% c(bad.kibx[-c(13)],vif.kibx)], collapse= "+"))), data=kib.zt)
car::vif(kibx)
confint(kibx)

goodvif.kibTMP2<- c("autre0.5","autre2","daupi","hr","pluie_pos_qt5","rg_pos","rg_recup","roche_nue2","t_min_interP","t_minP_qt5","t_moy_qt5","zt.tmaxP_44","zt.tminP_46")

################################################################################
################################################################################
##################### backward AIC #################################################

################################################################################
######### selection AIC bolitinos glmmTMB NB

## length(goodvif.bolTMP2) ## 18

bolTMB_mod0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2, collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))

bolTMB1.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(1)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(2)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(3)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(4)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(5)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(6)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB1.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(7)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(8)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(9)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(10)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(11)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB1.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(12)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(14)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.15 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(15)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.16 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(16)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.17 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(17)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB1.18 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(18)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))

AICtab(bolTMB1.1,bolTMB1.2,bolTMB1.3,bolTMB1.4,bolTMB1.5,bolTMB1.6,bolTMB1.7,bolTMB1.8,bolTMB1.9,bolTMB1.10,bolTMB1.11,bolTMB1.12,bolTMB1.13,bolTMB1.14,bolTMB1.15,bolTMB1.16,bolTMB1.17,bolTMB1.18,bolTMB_mod0) # 
AIC(bolTMB1.13) ## 1106.495

bolTMB2.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,1)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB2.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,2)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,3)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,4)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,5)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,6)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB2.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,7)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,8)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,9)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,10)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,12)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,14)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,15)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.15 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,16)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB2.16 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,17)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB2.17 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,18)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))

AICtab(bolTMB2.1,bolTMB2.2,bolTMB2.3,bolTMB2.4,bolTMB2.5,bolTMB2.6,bolTMB2.7,bolTMB2.8,bolTMB2.9,bolTMB2.10,bolTMB2.11,bolTMB2.12,bolTMB2.13,bolTMB2.14,bolTMB2.15,bolTMB2.16,bolTMB2.17) # 
AIC(bolTMB2.11) ## 1104.521

bolTMB3.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,1)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB3.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,2)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,3)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,4)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,5)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,6)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB3.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,7)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,8)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,9)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,10)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,12)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,14)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,15)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB3.15 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,17)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB3.16 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,18)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))

AICtab(bolTMB3.1,bolTMB3.2,bolTMB3.3,bolTMB3.4,bolTMB3.5,bolTMB3.6,bolTMB3.7,bolTMB3.8,bolTMB3.9,bolTMB3.10,bolTMB3.11,bolTMB3.12,bolTMB3.13,bolTMB3.14,bolTMB3.15,bolTMB3.16) # 
AIC(bolTMB3.14) ## 1102.645

bolTMB4.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,1)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB4.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,2)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,3)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,5)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,6)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB4.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,7)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,8)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,9)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,12)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,13)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,14)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,15)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB4.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,17)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB4.15 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,18)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 

AICtab(bolTMB4.1,bolTMB4.2,bolTMB4.3,bolTMB4.4,bolTMB4.5,bolTMB4.6,bolTMB4.7,bolTMB4.8,bolTMB4.9,bolTMB4.10,bolTMB4.11,bolTMB4.12,bolTMB4.13,bolTMB4.14,bolTMB4.15) # 
AIC(bolTMB4.4) ## 1100.818

bolTMB5.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,1)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB5.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,2)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,3)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,5)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,6)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,7)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB5.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,8)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,9)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,10)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,14)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,15)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,17)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB5.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,18)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))

AICtab(bolTMB5.1,bolTMB5.2,bolTMB5.3,bolTMB5.4,bolTMB5.5,bolTMB5.6,bolTMB5.7,bolTMB5.8,bolTMB5.9,bolTMB5.10,bolTMB5.11,bolTMB5.12,bolTMB5.13,bolTMB5.14) # 
AIC(bolTMB5.10) ## 1099.427

bolTMB6.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,1)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB6.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,3)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,5)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,6)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,7)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB6.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,8)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,9)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,10)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,14)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,15)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,17)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB6.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,18)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))

AICtab(bolTMB6.1,bolTMB6.2,bolTMB6.3,bolTMB6.4,bolTMB6.5,bolTMB6.6,bolTMB6.7,bolTMB6.8,bolTMB6.9,bolTMB6.10,bolTMB6.11,bolTMB6.12,bolTMB6.13) # 
AIC(bolTMB6.2) ##  1098.151

bolTMB7.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,1)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB7.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,3)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB7.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,5)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB7.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,6)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB7.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,7)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB7.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,8)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log")) 
bolTMB7.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,9)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB7.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,10)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB7.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,14)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB7.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,15)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB7.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,17)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))
bolTMB7.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.bolTMP2[-c(13,11,16,4,12,2,18)], collapse= "+"),"+(1|site)")), data=bol.zt, family=truncated_nbinom2(link = "log"))

AICtab(bolTMB7.1,bolTMB7.2,bolTMB7.3,bolTMB7.4,bolTMB7.5,bolTMB7.6,bolTMB7.7,bolTMB7.8,bolTMB7.9,bolTMB7.10,bolTMB7.11,bolTMB7.12) # 
AIC(bolTMB7.1) ## 1098.264 


## best bol NB glmmTMB: c("bov1","ouv_bat","plant_forest1","pluie_pos_qt5","pluie_recup_log10","rg_pos_qt4","rg_recup_qt3","savane0.5","zt.log_pluie_25.23","zt.logtminP30d_10","zt.pluie_9","zt.tmaxP_35")

################################################################################
######### selection AIC enderleini glmmTMB NB

## length(goodvif.enderTMP2) ## 11

enderTMB_mod0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2, collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))

enderTMB1.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(1)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB1.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB1.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(3)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB1.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(4)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB1.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(5)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB1.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(6)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB1.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(7)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB1.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(8)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB1.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(9)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))  
enderTMB1.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(10)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB1.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(11)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))

AICtab(enderTMB_mod0,enderTMB1.1,enderTMB1.2,enderTMB1.3,enderTMB1.4,enderTMB1.5,enderTMB1.6,enderTMB1.7,enderTMB1.8,enderTMB1.9,enderTMB1.10,enderTMB1.11) # 
AIC(enderTMB1.2) ## 299.4635 

enderTMB2.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,1)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB2.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,3)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB2.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,4)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB2.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,5)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB2.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,6)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB2.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,7)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB2.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,8)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB2.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,9)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB2.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,10)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))  
enderTMB2.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))

AICtab(enderTMB2.1,enderTMB2.2,enderTMB2.3,enderTMB2.4,enderTMB2.5,enderTMB2.6,enderTMB2.7,enderTMB2.8,enderTMB2.9,enderTMB2.10) # 
AIC(enderTMB2.10) ## 298.632

enderTMB3.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,1)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB3.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,3)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB3.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB3.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,5)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB3.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,6)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB3.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,7)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))  
enderTMB3.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,8)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB3.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,9)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB3.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,10)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))  

AICtab(enderTMB3.1,enderTMB3.2,enderTMB3.3,enderTMB3.4,enderTMB3.5,enderTMB3.6,enderTMB3.7,enderTMB3.8,enderTMB3.9) # 
AIC(enderTMB3.3) ## 298.1404 

enderTMB4.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,1)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB4.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,3)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB4.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,5)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB4.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,6)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB4.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB4.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,8)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))  
enderTMB4.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,9)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB4.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,10)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))  

AICtab(enderTMB4.1,enderTMB4.2,enderTMB4.3,enderTMB4.4,enderTMB4.5,enderTMB4.6,enderTMB4.7,enderTMB4.8) # 
AIC(enderTMB4.5) ## 296.3394

enderTMB5.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,1)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB5.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,3)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB5.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,5)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB5.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,6)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB5.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,8)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB5.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,9)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))  
enderTMB5.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,10)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))  

AICtab(enderTMB5.1,enderTMB5.2,enderTMB5.3,enderTMB5.4,enderTMB5.5,enderTMB5.6,enderTMB5.7) # 
AIC(enderTMB5.7) ## 295.1861

enderTMB6.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,10,1)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB6.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,10,3)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB6.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,10,5)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB6.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,10,6)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB6.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,10,8)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log"))
enderTMB6.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.enderTMP2[-c(2,11,4,7,10,9)], collapse= "+"),"+(1|site)")), data=ender.zt, family=truncated_nbinom2(link = "log")) 

AICtab(enderTMB6.1,enderTMB6.2,enderTMB6.3,enderTMB6.4,enderTMB6.5,enderTMB6.6) # 
AIC(enderTMB6.3) ##  295.4135

exp(confint(enderTMB5.7))
## best ender NB glmmTMB: c("daupi","petit_ru1","t_min_interP_log10","tot_anx1","vent_recup_qt5","zt.log_pluie_9")

################################################################################
######### selection AIC grahamii glmmTMB NB

## length(goodvif.grahTMP2) ## 14

grahTMB_mod0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2, collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

grahTMB1.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(1)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))  
grahTMB1.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(2)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))  
grahTMB1.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(3)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))  
grahTMB1.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(4)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))  
grahTMB1.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(5)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB1.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(6)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB1.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(7)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB1.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB1.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(9)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB1.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(10)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB1.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(11)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB1.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(12)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB1.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(13)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB1.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(14)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

AICtab(grahTMB1.1,grahTMB1.2,grahTMB1.3,grahTMB1.4,grahTMB1.5,grahTMB1.6,grahTMB1.7,grahTMB1.8,grahTMB1.9,grahTMB1.10,grahTMB1.11,grahTMB1.12,grahTMB1.13,grahTMB1.14,grahTMB_mod0) # 
AIC(grahTMB1.8) ## 571.1617  


grahTMB2.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,1)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log")) 
grahTMB2.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,2)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB2.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,3)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log")) 
grahTMB2.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,4)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log")) 
grahTMB2.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,5)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log")) 
grahTMB2.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,6)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB2.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,7)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB2.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,9)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log")) 
grahTMB2.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,10)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB2.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB2.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,12)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB2.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,13)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB2.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,14)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

AICtab(grahTMB2.1,grahTMB2.2,grahTMB2.3,grahTMB2.4,grahTMB2.5,grahTMB2.6,grahTMB2.7,grahTMB2.8,grahTMB2.9,grahTMB2.10,grahTMB2.11,grahTMB2.12,grahTMB2.13) # 
AIC(grahTMB2.10) ## 567.4357

grahTMB3.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,1)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,2)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,4)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,5)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,6)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,7)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))  
grahTMB3.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,9)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,10)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,12)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,13)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB3.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,14)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

AICtab(grahTMB3.1,grahTMB3.2,grahTMB3.3,grahTMB3.4,grahTMB3.5,grahTMB3.6,grahTMB3.7,grahTMB3.8,grahTMB3.9,grahTMB3.10,grahTMB3.11,grahTMB3.12) # 
AIC(grahTMB3.3) ##  563.0173

grahTMB4.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,1)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,2)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,4)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,5)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,6)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,7)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,9)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,10)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,12)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,13)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB4.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

AICtab(grahTMB4.1,grahTMB4.2,grahTMB4.3,grahTMB4.4,grahTMB4.5,grahTMB4.6,grahTMB4.7,grahTMB4.8,grahTMB4.9,grahTMB4.10,grahTMB4.11) # 
AIC(grahTMB4.11) ##  561.0629

grahTMB5.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,1)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB5.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,2)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB5.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,4)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB5.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,5)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB5.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,6)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB5.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,7)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB5.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,9)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB5.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB5.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,12)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB5.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,13)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

AICtab(grahTMB5.1,grahTMB5.2,grahTMB5.3,grahTMB5.4,grahTMB5.5,grahTMB5.6,grahTMB5.7,grahTMB5.8,grahTMB5.9,grahTMB5.10) # 
AIC(grahTMB5.8) ## 559.3875

grahTMB6.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,1)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB6.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,2)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB6.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,4)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB6.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,5)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB6.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,6)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB6.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,7)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB6.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB6.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,12)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB6.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,13)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

AICtab(grahTMB6.1,grahTMB6.2,grahTMB6.3,grahTMB6.4,grahTMB6.5,grahTMB6.6,grahTMB6.7,grahTMB6.8,grahTMB6.9) # 
AIC(grahTMB6.7) ## 557.8882

grahTMB7.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,1)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB7.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,2)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB7.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,4)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB7.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,5)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB7.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,6)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB7.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,7)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB7.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB7.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,13)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

AICtab(grahTMB7.1,grahTMB7.2,grahTMB7.3,grahTMB7.4,grahTMB7.5,grahTMB7.6,grahTMB7.7,grahTMB7.8) # 
AIC(grahTMB7.7) ## 556.7774

grahTMB8.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,1)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB8.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,2)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB8.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,4)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB8.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,5)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB8.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,6)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB8.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,7)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB8.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,13)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

AICtab(grahTMB8.1,grahTMB8.2,grahTMB8.3,grahTMB8.4,grahTMB8.5,grahTMB8.6,grahTMB8.7) # 
AIC(grahTMB8.2) ## 556.5719

grahTMB9.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,2,1)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB9.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,2,4)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB9.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,2,5)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB9.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,2,6)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB9.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,2,7)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))
grahTMB9.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.grahTMP2[-c(8,11,3,14,10,9,12,2,13)], collapse= "+"),"+(1|site)")), data=grah.zt, family=truncated_nbinom2(link = "log"))

AICtab(grahTMB9.1,grahTMB9.2,grahTMB9.3,grahTMB9.4,grahTMB9.5,grahTMB9.6) # 
AIC(grahTMB9.6) ## 558.1437

exp(confint(grahTMB8.2))

## best grah NB glmmTMB: c("daupi","ouv_bat","pluie_pos_qt5","pluie_recup_qt5","rg_pos_qt5","zt.ndvi_est_21")  ##  "nbsite0.5"

################################################################################
######### selection AIC imi glmmTMB NB

## length(goodvif.imiTMP2) ## 19

imiTMB_mod0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2, collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 

imiTMB1.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(1)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB1.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(2)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB1.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(3)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB1.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(4)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB1.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(5)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB1.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(6)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB1.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(7)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB1.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(8)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB1.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(9)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB1.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB1.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(11)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB1.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(12)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB1.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(13)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB1.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(14)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB1.15 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(15)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB1.16 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(16)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB1.17 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(17)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB1.18 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(18)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB1.19 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(19)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 

AICtab(imiTMB1.1,imiTMB1.2,imiTMB1.3,imiTMB1.4,imiTMB1.5,imiTMB1.6,imiTMB1.7,imiTMB1.8,imiTMB1.9,imiTMB1.10,imiTMB1.11,imiTMB1.12,imiTMB1.13,imiTMB1.14,imiTMB1.15,imiTMB1.16,imiTMB1.17,imiTMB1.18,imiTMB1.19,imiTMB_mod0) # 
AIC(imiTMB1.10) ## 2292.503


imiTMB2.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,1)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB2.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,2)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB2.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,3)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB2.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,4)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,5)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB2.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,7)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,8)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB2.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,9)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,11)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,12)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,13)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,14)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,15)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.15 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,16)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.16 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,17)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.17 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,18)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB2.18 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,19)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))

AICtab(imiTMB2.1,imiTMB2.2,imiTMB2.3,imiTMB2.4,imiTMB2.5,imiTMB2.6,imiTMB2.7,imiTMB2.8,imiTMB2.9,imiTMB2.10,imiTMB2.11,imiTMB2.12,imiTMB2.13,imiTMB2.14,imiTMB2.15,imiTMB2.16,imiTMB2.17,imiTMB2.18) # 
AIC(imiTMB2.6) ## 2290.529

imiTMB3.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,1)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB3.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,2)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB3.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,3)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB3.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,4)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,5)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,7)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB3.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,8)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB3.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,9)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB3.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,11)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,12)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,13)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,14)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,15)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,16)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.15 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,17)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.16 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,18)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB3.17 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))

AICtab(imiTMB3.1,imiTMB3.2,imiTMB3.3,imiTMB3.4,imiTMB3.5,imiTMB3.6,imiTMB3.7,imiTMB3.8,imiTMB3.9,imiTMB3.10,imiTMB3.11,imiTMB3.12,imiTMB3.13,imiTMB3.14,imiTMB3.15,imiTMB3.16,imiTMB3.17) # 
AIC(imiTMB3.17) ##   2288.738

imiTMB4.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,1)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB4.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,2)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB4.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB4.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,4)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB4.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,5)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB4.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,7)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB4.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,8)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB4.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,9)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB4.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,11)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB4.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,12)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB4.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,13)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB4.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,14)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB4.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,15)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB4.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,16)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB4.15 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,17)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB4.16 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,18)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))

AICtab(imiTMB4.1,imiTMB4.2,imiTMB4.3,imiTMB4.4,imiTMB4.5,imiTMB4.6,imiTMB4.7,imiTMB4.8,imiTMB4.9,imiTMB4.10,imiTMB4.11,imiTMB4.12,imiTMB4.13,imiTMB4.14,imiTMB4.15,imiTMB4.16) # 
AIC(imiTMB4.3) ## 2286.884

imiTMB5.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,1)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB5.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,2)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB5.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB5.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,5)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB5.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,7)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB5.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,8)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB5.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,9)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB5.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,11)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB5.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,12)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB5.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,13)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB5.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,14)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB5.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,15)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))     
imiTMB5.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,16)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))     
imiTMB5.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,17)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))     
imiTMB5.15 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,18)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))        

AICtab(imiTMB5.1,imiTMB5.2,imiTMB5.3,imiTMB5.4,imiTMB5.5,imiTMB5.6,imiTMB5.7,imiTMB5.8,imiTMB5.9,imiTMB5.10,imiTMB5.11,imiTMB5.12,imiTMB5.13,imiTMB5.14,imiTMB5.15) # 
AIC(imiTMB5.3) ## 2285.075

imiTMB6.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,1)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB6.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,2)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB6.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,5)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB6.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,7)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB6.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,8)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB6.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,9)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB6.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,11)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB6.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,12)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB6.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,13)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB6.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,14)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB6.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB6.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,16)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB6.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,17)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB6.14 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,18)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))     

AICtab(imiTMB6.1,imiTMB6.2,imiTMB6.3,imiTMB6.4,imiTMB6.5,imiTMB6.6,imiTMB6.7,imiTMB6.8,imiTMB6.9,imiTMB6.10,imiTMB6.11,imiTMB6.12,imiTMB6.13,imiTMB6.14) # 
AIC(imiTMB6.11) ##  2283.318

imiTMB7.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,1)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB7.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,2)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB7.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,5)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB7.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,7)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB7.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,8)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB7.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,9)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB7.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,11)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB7.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,12)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB7.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,13)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB7.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,14)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB7.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB7.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,17)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB7.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,18)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   

AICtab(imiTMB7.1,imiTMB7.2,imiTMB7.3,imiTMB7.4,imiTMB7.5,imiTMB7.6,imiTMB7.7,imiTMB7.8,imiTMB7.9,imiTMB7.10,imiTMB7.11,imiTMB7.12,imiTMB7.13) # 
AIC(imiTMB7.11) ## 2281.483

imiTMB8.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,1)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB8.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,2)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB8.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,5)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB8.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,7)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB8.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,8)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB8.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,9)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB8.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,11)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB8.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,12)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB8.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,13)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB8.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB8.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,17)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB8.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,18)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   

AICtab(imiTMB8.1,imiTMB8.2,imiTMB8.3,imiTMB8.4,imiTMB8.5,imiTMB8.6,imiTMB8.7,imiTMB8.8,imiTMB8.9,imiTMB8.10,imiTMB8.11,imiTMB8.12) # 
AIC(imiTMB8.10) ## 2280.014

imiTMB9.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,1)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB9.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,2)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB9.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,5)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB9.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,7)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB9.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,8)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))
imiTMB9.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,9)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB9.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,11)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))  
imiTMB9.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,12)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB9.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,13)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   
imiTMB9.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,17)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log")) 
imiTMB9.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.imiTMP2[-c(10,6,19,3,4,15,16,14,18)], collapse= "+"),"+(1|site)")), data=imi.zt, family=truncated_nbinom2(link = "log"))   

AICtab(imiTMB9.1,imiTMB9.2,imiTMB9.3,imiTMB9.4,imiTMB9.5,imiTMB9.6,imiTMB9.7,imiTMB9.8,imiTMB9.9,imiTMB9.10,imiTMB9.11) # 
AIC(imiTMB9.6) ##  2281.584

exp(confint(imiTMB5.6))
## best imi NB glmmTMB: c("autre2","daupi","ndvi_est_qt5","plant_forest1","pluie_pos_qt5","pluie_recup","roche_nue2","t_max_interP","t_maxP","zt.hr30d_26","zt.ndvi_est_50") ##  

################################################################################
######### selection AIC kib glmmTMB NB

## length(goodvif.kibTMP2) ## 13

kibTMB_mod0 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2, collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log")) 

kibTMB1.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(1)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(2)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(3)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(4)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(5)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB1.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(6)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(7)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(8)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(9)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(10)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(12)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB1.13 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(13)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))


AICtab(kibTMB_mod0,kibTMB1.1,kibTMB1.2,kibTMB1.3,kibTMB1.4,kibTMB1.5,kibTMB1.6,kibTMB1.7,kibTMB1.8,kibTMB1.9,kibTMB1.10,kibTMB1.11,kibTMB1.12,kibTMB1.13) # 
AIC(kibTMB1.11) ## 1892.01 

kibTMB2.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,1)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB2.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,2)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB2.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,3)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB2.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,4)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB2.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,5)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB2.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,6)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB2.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,7)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB2.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB2.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,9)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB2.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,10)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB2.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,12)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB2.12 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,13)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))

AICtab(kibTMB2.1,kibTMB2.2,kibTMB2.3,kibTMB2.4,kibTMB2.5,kibTMB2.6,kibTMB2.7,kibTMB2.8,kibTMB2.9,kibTMB2.10,kibTMB2.11,kibTMB2.12) # 
AIC(kibTMB2.8) ## 1890.511

kibTMB3.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,1)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB3.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,2)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB3.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,3)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB3.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,4)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB3.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,5)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB3.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,6)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB3.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,7)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB3.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,9)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB3.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,10)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB3.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,12)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB3.11 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))

AICtab(kibTMB3.1,kibTMB3.2,kibTMB3.3,kibTMB3.4,kibTMB3.5,kibTMB3.6,kibTMB3.7,kibTMB3.8,kibTMB3.9,kibTMB3.10,kibTMB3.11) # 
AIC(kibTMB3.11) ## 1889.523

kibTMB4.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,1)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB4.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,2)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB4.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,3)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB4.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,4)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB4.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,5)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB4.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB4.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,7)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB4.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,9)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB4.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,10)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB4.10 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,12)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))

AICtab(kibTMB4.1,kibTMB4.2,kibTMB4.3,kibTMB4.4,kibTMB4.5,kibTMB4.6,kibTMB4.7,kibTMB4.8,kibTMB4.9,kibTMB4.10) # 
AIC(kibTMB4.6) ##  1888.764

kibTMB5.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,1)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB5.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,2)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB5.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,3)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB5.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,4)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB5.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,5)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB5.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,7)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB5.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,9)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB5.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,10)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB5.9 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,12)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))

AICtab(kibTMB5.1,kibTMB5.2,kibTMB5.3,kibTMB5.4,kibTMB5.5,kibTMB5.6,kibTMB5.7,kibTMB5.8,kibTMB5.9,kibTMB5.10) # 
AIC(kibTMB5.4) ## 1888.634 

kibTMB6.1 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,4,1)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB6.2 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,4,2)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB6.3 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,4,3)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB6.4 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,4,5)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB6.5 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,4,7)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB6.6 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,4,9)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))
kibTMB6.7 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,4,10)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))  
kibTMB6.8 <- glmmTMB(as.formula(paste("nombre ~ ", paste(goodvif.kibTMP2[-c(11,8,13,6,4,12)], collapse= "+"),"+(1|site)")), data=kib.zt, family=truncated_nbinom2(link = "log"))

AICtab(kibTMB6.1,kibTMB6.2,kibTMB6.3,kibTMB6.4,kibTMB6.5,kibTMB6.6,kibTMB6.7,kibTMB6.8) # 
AIC(kibTMB6.5) ## 1889.196
exp(confint(kibTMB5.6))

## best kib NB glmmTMB: c("autre0.5","autre2","daupi","pluie_pos_qt5",rg_recup","t_min_interP","t_minP_qt5","zt.tmaxP_44") ## "hr" 










