################################################################################
########### HURDLE MODEL #######################################################

## all data
bol_tt3     <-read.table("bol_tt3.txt",header=T)  
ender_tt3   <-read.table("ender_tt3.txt",header=T)
grah_tt3    <-read.table("grah_tt3.txt",header=T)
imi_tt3     <-read.table("imi_tt3.txt",header=T)
kib_tt3     <-read.table("kib_tt3.txt",header=T)

# summary(bol.ent)
## training data
bol.HD1an  <- read.table("bol.ent.txt",header=T)
ender.HD1an<- read.table("ender.ent.txt",header=T)
grah.HD1an <- read.table("grah.ent.txt",header=T)
imi.HD1an  <- read.table("imi.ent.txt",header=T)
kib.HD1an  <- read.table("kib.ent.txt",header=T)

## external validation data
bol.HD2an  <- read.table("bol.ve.txt",header=T)
ender.HD2an<- read.table("ender.ve.txt",header=T)
grah.HD2an <- read.table("grah.ve.txt",header=T)
imi.HD2an  <- read.table("imi.ve.txt",header=T)
kib.HD2an  <- read.table("kib.ve.txt",header=T)

## zero-truncated data
bol.zt.tt  <- bol_tt3[bol_tt3$nombre > 0 ,]
ender.zt.tt<- ender_tt3[ender_tt3$nombre > 0 ,]
grah.zt.tt <- grah_tt3[grah_tt3$nombre > 0 ,]
imi.zt.tt  <- imi_tt3[imi_tt3$nombre > 0 ,]
kib.zt.tt  <- kib_tt3[kib_tt3$nombre > 0 ,]

bol.ent.zt  <- bol.HD1an[bol.HD1an$nombre > 0 ,]
ender.ent.zt<- ender.HD1an[ender.HD1an$nombre > 0 ,]
grah.ent.zt <- grah.HD1an[grah.HD1an$nombre > 0 ,]
imi.ent.zt  <- imi.HD1an[imi.HD1an$nombre > 0 ,]
kib.ent.zt  <- kib.HD1an[kib.HD1an$nombre > 0 ,]

##### donnes prdiction validation interne
## internal validation prediction
pred.bolmm     <-read.table("pred.bolmm2.txt",header=T)  
pred.endermm   <-read.table("pred.endermm2.txt",header=T)
pred.grahmm    <-read.table("pred.grahmm2.txt",header=T)
pred.imimm     <-read.table("pred.imimm2.txt",header=T)
pred.kibmm     <-read.table("pred.kiblmm2.txt",header=T)

################################################################################
### load logistics and count models

### logistic models

 load("tribin.bol_mod32")
 load("tribin.ender_mod32")
 load("tribin.grah_mod32")
 load("tribin.imi_mod32")
 load("tribin.kib_mod32")

### count models
 
 load("bolTMB2")                
 load("enderTMB2")            
 load("grahTMB2")               
 load("imiTMB2")                
 load("kibTMB2") 
 
################################################################################
### variables of the count models for internal validation

best_bol.TMB<-c("bov1","ouv_bat","plant_forest1","pluie_pos_qt5","pluie_recup_log10","rg_pos_qt4","rg_recup_qt3","savane0.5","zt.log_pluie_25.23","zt.logtminP30d_10","zt.pluie_9","zt.tmaxP_35")
best_ender.TMB<-c("daupi","petit_ru1","t_min_interP_log10","tot_anx1","vent_recup_qt5","zt.log_pluie_9")
best_grah.TMB<-c("daupi","ouv_bat","pluie_pos_qt5","pluie_recup_qt5","rg_pos_qt5","zt.ndvi_est_21")  ##  "nbsite0.5"
best_imi.TMB<-c("autre2","daupi","ndvi_est_qt5","plant_forest1","pluie_pos_qt5","pluie_recup","roche_nue2","t_max_interP","t_maxP","zt.hr30d_26","zt.ndvi_est_50") 
best_kib.TMB<-c("autre0.5","autre2","daupi","pluie_pos_qt5","rg_recup","t_min_interP","t_minP_qt5","zt.tmaxP_44") ## "hr" 

################################################################################
### library 

library(glmmTMB)
trnb<-"truncated_nbinom2" 
lien<-"log"

library(PresenceAbsence)

library(doParallel) 
library(foreach)
## install.packages("doParallel")
## install.packages("foreach")

library(dplyr)
#library(coefplot)
library(epiDisplay)
library(bbmle)
library(MLmetrics)
library(ggplot2)
library(smooth)
library(hydroGOF)

################################################################################
############# abundance prediction #############################################
################################################################################

######## threshold for a positive realization maximizing sensitivity and specificity

## for training data
P.bol.ent<- optimal.thresholds(DATA = cbind(c(1:length(bol.HD1an$BME)),as.numeric(bol.HD1an$BME),as.numeric(bol.HD1an$pred.BME.ent)), opt.methods = "MaxSens+Spec")[1,2]        
P.ender.ent<- optimal.thresholds(DATA = cbind(c(1:length(ender.HD1an$BME)),as.numeric(ender.HD1an$BME),as.numeric(ender.HD1an$pred.BME.ent)), opt.methods = "MaxSens+Spec")[1,2] 
P.grah.ent<- optimal.thresholds(DATA = cbind(c(1:length(grah.HD1an$BME)),as.numeric(grah.HD1an$BME),as.numeric(grah.HD1an$pred.BME.ent)), opt.methods = "MaxSens+Spec")[1,2] 
P.imi.ent<- optimal.thresholds(DATA = cbind(c(1:length(imi.HD1an$BME)),as.numeric(imi.HD1an$BME),as.numeric(imi.HD1an$pred.BME.ent)), opt.methods = "MaxSens+Spec")[1,2]
P.kib.ent<- optimal.thresholds(DATA = cbind(c(1:length(kib.HD1an$BME)),as.numeric(kib.HD1an$BME),as.numeric(kib.HD1an$pred.BME.ent)), opt.methods = "MaxSens+Spec")[1,2]

## for internal validation data
P.bol.vi<- optimal.thresholds(DATA = cbind(c(1:length(bol.HD1an$BME)),as.numeric(bol.HD1an$BME),as.numeric(bol.HD1an$pred.BME.vi)), opt.methods = "MaxSens+Spec")[1,2]
P.ender.vi<- optimal.thresholds(DATA = cbind(c(1:length(ender.HD1an$BME)),as.numeric(ender.HD1an$BME),as.numeric(ender.HD1an$pred.BME.vi)), opt.methods = "MaxSens+Spec")[1,2]
P.grah.vi<- optimal.thresholds(DATA = cbind(c(1:length(grah.HD1an$BME)),as.numeric(grah.HD1an$BME),as.numeric(grah.HD1an$pred.BME.vi)), opt.methods = "MaxSens+Spec")[1,2]
P.imi.vi<- optimal.thresholds(DATA = cbind(c(1:length(imi.HD1an$BME)),as.numeric(imi.HD1an$BME),as.numeric(imi.HD1an$pred.BME.vi)), opt.methods = "MaxSens+Spec")[1,2]
P.kib.vi<- optimal.thresholds(DATA = cbind(c(1:length(kib.HD1an$BME)),as.numeric(kib.HD1an$BME),as.numeric(kib.HD1an$pred.BME.vi)), opt.methods = "MaxSens+Spec")[1,2]

## for external validation data
P.bol.ve<- optimal.thresholds(DATA = cbind(c(1:length(bol.HD2an$BME)),as.numeric(bol.HD2an$BME),as.numeric(bol.HD2an$pred.BME.ve)), opt.methods = "MaxSens+Spec")[1,2]
P.ender.ve<- optimal.thresholds(DATA = cbind(c(1:length(ender.HD2an$BME)),as.numeric(ender.HD2an$BME),as.numeric(ender.HD2an$pred.BME.ve)), opt.methods = "MaxSens+Spec")[1,2]
P.grah.ve<- optimal.thresholds(DATA = cbind(c(1:length(grah.HD2an$BME)),as.numeric(grah.HD2an$BME),as.numeric(grah.HD2an$pred.BME.ve)), opt.methods = "MaxSens+Spec")[1,2]
P.imi.ve<- optimal.thresholds(DATA = cbind(c(1:length(imi.HD2an$BME)),as.numeric(imi.HD2an$BME),as.numeric(imi.HD2an$pred.BME.ve)), opt.methods = "MaxSens+Spec")[1,2]
P.kib.ve<- optimal.thresholds(DATA = cbind(c(1:length(kib.HD2an$BME)),as.numeric(kib.HD2an$BME),as.numeric(kib.HD2an$pred.BME.ve)), opt.methods = "MaxSens+Spec")[1,2]

################################################################################
###### prdict abundance on training data
            
bol.HD1an$HD.entTMB <- ifelse(bol.HD1an$pred.BME.ent<P.bol.ent, 0, predict(bolTMB,newdata=bol.HD1an,type="response",allow.new.levels=TRUE))
               
ender.HD1an$HD.entTMB <- ifelse(ender.HD1an$pred.BME.ent<P.ender.ent, 0, predict(enderTMB,newdata=ender.HD1an,type="response",allow.new.levels=TRUE))
                
grah.HD1an$HD.entTMB <- ifelse(grah.HD1an$pred.BME.ent<P.grah.ent, 0, predict(grahTMB,newdata=grah.HD1an,type="response",allow.new.levels=TRUE))
              
imi.HD1an$HD.entTMB <- ifelse(imi.HD1an$pred.BME.ent<P.imi.ent, 0, predict(imiTMB,newdata=imi.HD1an,type="response",allow.new.levels=TRUE))
               
kib.HD1an$HD.entTMB <- ifelse(kib.HD1an$pred.BME.ent<P.kib.ent, 0, predict(kibTMB,newdata=kib.HD1an,type="response",allow.new.levels=TRUE))

################################################################################
######### internal validation ########################################
######### requires several minutes
registerDoParallel(4) ## 

##################################### negative binomial glmmTMB
pred.bol.ztTMB<-foreach(i=1:nrow(bol.HD1an), .combine="c")%do%
{predloozt <- ifelse(bol.HD1an$pred.BME.vi[i]<P.bol.vi,0, predict(glmmTMB(formula(bolTMB), data=subset(bol.HD1an[-i,],nombre>0), family=truncated_nbinom2(link = "log")),bol.HD1an[i,],type="response"))}

pred.ender.ztTMB<-foreach(i=1:nrow(ender.HD1an), .combine="c")%do%
{predloozt <- ifelse(ender.HD1an$pred.BME.vi[i]<P.ender.vi,0, predict(glmmTMB(formula(enderTMB), data=subset(ender.HD1an[-i,],nombre>0), family=truncated_nbinom2(link = "log")),ender.HD1an[i,],type="response"))}

pred.grah.ztTMB<-foreach(i=1:nrow(grah.HD1an), .combine="c")%do%
{predloozt <- ifelse(grah.HD1an$pred.BME.vi[i]<P.grah.vi,0, predict(glmmTMB(formula(grahTMB), data=subset(grah.HD1an[-i,],nombre>0), family=truncated_nbinom2(link = "log")),grah.HD1an[i,],type="response"))}

pred.imi.ztTMB<-foreach(i=1:nrow(imi.HD1an), .combine="c")%do%
{predloozt <- ifelse(imi.HD1an$pred.BME.vi[i]<P.imi.vi,0, predict(glmmTMB(formula(imiTMB), data=subset(imi.HD1an[-i,],nombre>0), family=truncated_nbinom2(link = "log")),imi.HD1an[i,],type="response"))}

pred.kib.ztTMB<-foreach(i=1:nrow(kib.HD1an), .combine="c")%do%
{predloozt <- ifelse(kib.HD1an$pred.BME.vi[i]<P.kib.vi,0, predict(glmmTMB(formula(kibTMB), data=subset(kib.HD1an[-i,],nombre>0), family=truncated_nbinom2(link = "log")),kib.HD1an[i,],type="response"))}

### save

##### predict abundance internal validation
               
bol.HD1an$HD.viTMB <- ifelse(bol.HD1an$pred.BME.vi<P.bol.vi, 0, pred.bol.ztTMB$x)
                
ender.HD1an$HD.viTMB <- ifelse(ender.HD1an$pred.BME.vi<P.ender.vi, 0, pred.ender.ztTMB$x)
               
grah.HD1an$HD.viTMB <- ifelse(grah.HD1an$pred.BME.vi<P.grah.vi, 0, pred.grah.ztTMB$x)
               
imi.HD1an$HD.viTMB <- ifelse(imi.HD1an$pred.BME.vi<P.imi.vi, 0, pred.imi.ztTMB$x)
               
kib.HD1an$HD.viTMB <- ifelse(kib.HD1an$pred.BME.vi<P.kib.vi, 0, pred.kib.ztTMB$x)

################################################################################
###### predict abundance external validation
               
bol.HD2an$HD.veTMB <- ifelse(bol.HD2an$pred.BME.ve<P.bol.ve, 0, predict(bolTMB,newdata=bol.HD2an,type="response",allow.new.levels=TRUE))
                
ender.HD2an$HD.veTMB <- ifelse(ender.HD2an$pred.BME.ve<P.ender.ve, 0, predict(enderTMB,newdata=ender.HD2an,type="response",allow.new.levels=TRUE))
                
grah.HD2an$HD.veTMB <- ifelse(grah.HD2an$pred.BME.ve<P.grah.ve, 0, predict(grahTMB,newdata=grah.HD2an,type="response",allow.new.levels=TRUE))
               
imi.HD2an$HD.veTMB <- ifelse(imi.HD2an$pred.BME.ve<P.imi.ve, 0, predict(imiTMB,newdata=imi.HD2an,type="response",allow.new.levels=TRUE))
              
kib.HD2an$HD.veTMB <- ifelse(kib.HD2an$pred.BME.ve<P.kib.ve, 0, predict(kibTMB,newdata=kib.HD2an,type="response",allow.new.levels=TRUE))

################################################################################
###### abundance prediction on global data with training data model
bol_tt3$HD.TMBcv <- ifelse(predict(tribin.bol_mod3,newdata=bol_tt3,type="response") <P.bol.ent, 0, predict(bolTMB,newdata=bol_tt3,type="response",allow.new.levels=TRUE))              
ender_tt3$HD.TMBcv <- ifelse(predict(tribin.ender_mod3,newdata=ender_tt3,type="response") <P.ender.ent, 0, predict(enderTMB,newdata=ender_tt3,type="response",allow.new.levels=TRUE))              
grah_tt3$HD.TMBcv <- ifelse(predict(tribin.grah_mod3,newdata=grah_tt3,type="response") <P.grah.ent, 0, predict(grahTMB,newdata=grah_tt3,type="response",allow.new.levels=TRUE))
imi_tt3$HD.TMBcv <- ifelse(predict(tribin.imi_mod3,newdata=imi_tt3,type="response") <P.imi.ent, 0, predict(imiTMB,newdata=imi_tt3,type="response",allow.new.levels=TRUE))
kib_tt3$HD.TMBcv <- ifelse(predict(tribin.kib_mod3,newdata=kib_tt3,type="response") <P.kib.ent, 0, predict(kibTMB,newdata=kib_tt3,type="response",allow.new.levels=TRUE))

####### save

################################################################################
################################################################################
## AIC hurdle

## AIC on training data
AIC(bolTMB) * (1- nrow(bol.ent.zt)/nrow(bol.HD1an))+ AIC (tribin.bol_mod3)                 ##  948.2  dont logistique: 330.5   et ztnb:  1098.2
AIC(enderTMB) * (1- nrow(ender.ent.zt)/nrow(ender.HD1an))+ AIC (tribin.ender_mod3)         ##  409.5  dont logistique: 154.5   et ztnb:  295.2
AIC(grahTMB) * (1- nrow(grah.ent.zt)/nrow(grah.HD1an))+ AIC (tribin.grah_mod3)             ##  705.3  dont logistique: 312.1   et ztnb:  556.6
AIC(imiTMB) * (1- nrow(imi.ent.zt)/nrow(imi.HD1an))+ AIC (tribin.imi_mod3)                 ##  1222.0 dont logistique: 261.7   et ztnb:  2280.0
AIC(kibTMB) * (1- nrow(kib.ent.zt)/nrow(kib.HD1an))+ AIC (tribin.kib_mod3)                 ##  1222.6 dont logistique: 322.0   et ztnb:  1888.6

## variable importance: cf. absolute value of z value 
summary(tribin.bol_mod3)
summary(bolTMB)

################################################################################
############### NRMSE

## training data
 nrmse(bol.HD1an$HD.entTMB, bol.HD1an$nombre,norm="maxmin") 
 nrmse(ender.HD1an$HD.entTMB, ender.HD1an$nombre,norm="maxmin")  
 nrmse(grah.HD1an$HD.entTMB, grah.HD1an$nombre,norm="maxmin")  
 nrmse(imi.HD1an$HD.entTMB, imi.HD1an$nombre,norm="maxmin")  
 nrmse(kib.HD1an$HD.entTMB, kib.HD1an$nombre,norm="maxmin")  

 ## internal validation
 nrmse(bol.HD1an$HD.viTMB, bol.HD1an$nombre,norm="maxmin") 
 nrmse(ender.HD1an$HD.viTMB, ender.HD1an$nombre,norm="maxmin")  
 nrmse(grah.HD1an$HD.viTMB, grah.HD1an$nombre,norm="maxmin")  
 nrmse(imi.HD1an$HD.viTMB, imi.HD1an$nombre,norm="maxmin")  
 nrmse(kib.HD1an$HD.viTMB, kib.HD1an$nombre,norm="maxmin")  

 ## external validation
 nrmse(bol.HD2an$HD.veTMB, bol.HD2an$nombre,norm="maxmin") 
 nrmse(ender.HD2an$HD.veTMB, ender.HD2an$nombre,norm="maxmin")  
 nrmse(grah.HD2an$HD.veTMB, grah.HD2an$nombre,norm="maxmin")  
 nrmse(imi.HD2an$HD.veTMB, imi.HD2an$nombre,norm="maxmin")  
 nrmse(kib.HD2an$HD.veTMB, kib.HD2an$nombre,norm="maxmin") 

 ## for prediction on all data
 nrmse(bol_tt3$HD.TMBcv, bol_tt3$nombre,norm="maxmin")   

###### significant variables and extraction of incidence rate ratio

mod.ztTMB<-list(bolTMBtt3,enderTMBtt3,grahTMBtt3,imiTMBtt3,kibTMBtt3)
names(mod.ztTMB)<- c("bolTMBtt3","enderTMBtt3","grahTMBtt3","imiTMBtt3","kibTMBtt3")

## significant variable
ano.ztTMB <- lapply(mod.ztTMB, function(x) Anova.II.glmmTMB(x))   ## fonction Anova.II.glmmTMB  executer depuis le fichier correspondant

## incidence rate ratio
coef.ztTMB<- lapply(mod.ztTMB, function(x) cbind(round(exp(fixef(x)$cond),3),round(exp(confint(x)[,c(1,2)]),3))) ## le IRR


############# re-estimate the coefficients with all the data ... according to cheng et al. 2010 Real longitudinal data analysis for real people: building a good enough mixed model
### only if all validation were ok

bolTMBtt3 <- glmmTMB(formula(bolTMB), data=bol.zt.tt, family=truncated_nbinom2(link = "log"))
enderTMBtt3 <- glmmTMB(formula(enderTMB), data=ender.zt.tt, family=truncated_nbinom2(link = "log"))
grahTMBtt3 <- glmmTMB(formula(grahTMB), data=grah.zt.tt, family=truncated_nbinom2(link = "log"))
imiTMBtt3 <- glmmTMB(formula(imiTMB), data=imi.zt.tt, family=truncated_nbinom2(link = "log"))
kibTMBtt3 <- glmmTMB(formula(kibTMB), data=kib.zt.tt, family=truncated_nbinom2(link = "log"))

P.bol<- optimal.thresholds(DATA = cbind(c(1:length(bol_tt3$BME)),as.numeric(bol_tt3$BME),as.numeric(bol_tt3$pred.BME)), opt.methods = "MaxSens+Spec")[1,2]
P.ender<- optimal.thresholds(DATA = cbind(c(1:length(ender_tt3$BME)),as.numeric(ender_tt3$BME),as.numeric(ender_tt3$pred.BME)), opt.methods = "MaxSens+Spec")[1,2]
P.grah<- optimal.thresholds(DATA = cbind(c(1:length(grah_tt3$BME)),as.numeric(grah_tt3$BME),as.numeric(grah_tt3$pred.BME)), opt.methods = "MaxSens+Spec")[1,2]
P.imi<- optimal.thresholds(DATA = cbind(c(1:length(imi_tt3$BME)),as.numeric(imi_tt3$BME),as.numeric(imi_tt3$pred.BME)), opt.methods = "MaxSens+Spec")[1,2]
P.kib<- optimal.thresholds(DATA = cbind(c(1:length(kib_tt3$BME)),as.numeric(kib_tt3$BME),as.numeric(kib_tt3$pred.BME)), opt.methods = "MaxSens+Spec")[1,2]

bol_tt3$HD.TMB <- ifelse(bol_tt3$pred.BME<P.bol, 0, predict(bolTMBtt3,newdata=bol_tt3,type="response",allow.new.levels=TRUE))              
ender_tt3$HD.TMB <- ifelse(ender_tt3$pred.BME<P.ender, 0, predict(enderTMBtt3,newdata=ender_tt3,type="response",allow.new.levels=TRUE))              
grah_tt3$HD.TMB <- ifelse(grah_tt3$pred.BME<P.grah, 0, predict(grahTMBtt3,newdata=grah_tt3,type="response",allow.new.levels=TRUE))
imi_tt3$HD.TMB <- ifelse(imi_tt3$pred.BME<P.imi, 0, predict(imiTMBtt3,newdata=imi_tt3,type="response",allow.new.levels=TRUE))
kib_tt3$HD.TMB <- ifelse(kib_tt3$pred.BME<P.kib, 0, predict(kibTMBtt3,newdata=kib_tt3,type="response",allow.new.levels=TRUE))

################################################################################
################################################################################
############ graphical output ################################################

culi_tt3<-bol_tt3
culi_tt3$date<-as.Date(culi_tt3$date)

### 

gg1<-ggplot(culi_tt3, aes(date, nombre))
gg1<- gg1 + geom_line(linetype="dashed", size=0.5)
gg1<- gg1 + geom_point()
gg1<- gg1 + geom_line(aes(y=HD.TMB),color="red",size=1)
gg1<- gg1 + theme_bw()
#gg1<- gg1 + geom_smooth(method="loess", se=TRUE)
gg1<- gg1 + facet_wrap(~num_site)
# gg1<- gg1 + annotate("text", x = 30, y = 150, color="red", label = "ZTNB by glmmADMB")
gg1<- gg1 + scale_y_log10(limits=c(0.1, 10000))
gg1 


